/*
 * dnsdict6.h (c) 2012 by van Hauser / THC
 *
 */

// buil-in list of subdomains
char *sub_small[] = {
  "www",
  "mail",
  "ftp",
  "pop",
  "ipv6",
  "smtp",
  "ns1",
  "webmail",
  "ns2",
  "sql",
  "ns",
  "imap",
  "ntp",
  "www6",
  "irc",
  "pop3",
  "wiki",
  "news",
  "dns",
  "blog",
  "test",
  "proxy",
  "time",
  "ntp1",
  "mx",
  "v6",
  "gw",
  "mailhost",
  "6to4",
  "mail6",
  "ip6",
  "tunnel",
  "firewall",
  "mx6",
  "ipv6-gw",
  "gw6",
  "www-ipv6",
  "video6",
  "v6gw",
  "nsv6",
  "ipv6gw",
  "www-v6",
  "v6www",
  "6net",
  "6",
  "ipv6-router",
  "blog6",
  "wwwv6",
  "wwwipv6",
  "www-6",
  ""
};

char *sub_medium[] = {
  "www",
  "mail",
  "ftp",
  "pop",
  "ipv6",
  "smtp",
  "ns1",
  "webmail",
  "ns2",
  "sql",
  "localhost",
  "ns",
  "imap",
  "ntp",
  "www6",
  "ip6test",
  "ipv6test",
  "6test",
  "test6",
  "testip6",
  "testipv6",
  "www6test",
  "test6www",
  "wwwtest6",
  "ns3",
  "irc",
  "pop3",
  "wiki",
  "news",
  "dns",
  "jabber",
  "blog",
  "svn",
  "www2",
  "ns4",
  "test",
  "dns2",
  "proxy",
  "mirror",
  "ldap",
  "time",
  "ntp1",
  "lists",
  "mx",
  "ntp2",
  "web",
  "mx1",
  "forum",
  "nagios",
  "ns0",
  "ns6",
  "v6",
  "irc6",
  "noc",
  "debian",
  "cvs",
  "gw",
  "admin",
  "mailhost",
  "home",
  "dev",
  "backup",
  "mx2",
  "sip",
  "ns5",
  "mrtg",
  "git",
  "dns1",
  "vpn",
  "sslvpn",
  "ssl-vpn",
  "lg",
  "whois",
  "mail2",
  "monitor",
  "voip",
  "stats",
  "www1",
  "intranet",
  "rt",
  "portal",
  "6to4",
  "www3",
  "ssh",
  "ns02",
  "mysql",
  "rsync",
  "relay",
  "gallery",
  "tv",
  "static",
  "router",
  "db",
  "login",
  "ftp1",
  "new",
  "mail1",
  "a",
  "mirrors",
  "media",
  "mail6",
  "loghost",
  "freebsd",
  "secure",
  "ftp2",
  "conference",
  "support",
  "ip6",
  "users",
  "ca",
  "weblog",
  "video",
  "my",
  "beta",
  "radius",
  "m",
  "cache",
  "wap",
  "ubuntu",
  "syslog",
  "shell",
  "search",
  "ip",
  "images",
  "wpad",
  "ur01",
  "ns7",
  "munin",
  "mobile",
  "linux",
  "ldap2",
  "b",
  "zeus",
  "radio",
  "loopback0",
  "info",
  "gate",
  "chat",
  "calendar",
  "stream",
  "smtp1",
  "service",
  "server",
  "radius2",
  "radius1",
  "old",
  "hosting",
  "bbs",
  "ns01",
  "net",
  "mail3",
  "c",
  "tracker",
  "ntp0",
  "nic",
  "mx0",
  "kerberos",
  "ftp6",
  "bbs6",
  "x",
  "staff",
  "smokeping",
  "nntp",
  "nms",
  "ldap1",
  "idp",
  "ftp3",
  "files",
  "alpha",
  "ad",
  "web1",
  "ur02",
  "tunnel",
  "tools",
  "stat",
  "sixxs",
  "resolver",
  "photo",
  "newsfeed",
  "moodle",
  "lab",
  "i",
  "gentoo",
  "download",
  "dns3",
  "d",
  "bugs",
  "api",
  "alice",
  "staging",
  "sirius",
  "services",
  "s",
  "rss",
  "ra",
  "php",
  "phoenix",
  "monitoring",
  "master",
  "fs",
  "data",
  "blogs",
  "web2",
  "streaming",
  "pluto",
  "people",
  "orange",
  "iptv",
  "hermes",
  "forums",
  "enterprise",
  "webstats",
  "webcam",
  "ssl",
  "s1",
  "r01",
  "mx6",
  "mx3",
  "merlin",
  "live",
  "lib",
  "janus",
  "iphone",
  "imaps",
  "help",
  "hades",
  "email",
  "doc",
  "dhcp",
  "venus",
  "turing",
  "ticket",
  "sun",
  "root",
  "projects",
  "post",
  "pki",
  "pbx",
  "office",
  "ns10",
  "mars",
  "library",
  "labs",
  "jupiter",
  "id",
  "gateway",
  "f",
  "efnet",
  "e",
  "dragon",
  "docs",
  "cisco",
  "bb",
  "autodiscover",
  "atlas",
  "ae-1",
  "win",
  "w",
  "v",
  "user",
  "ts",
  "titan",
  "teredo",
  "software",
  "sms",
  "six",
  "r02",
  "project",
  "ms",
  "mon",
  "keyserver",
  "ipv6-gw",
  "internal",
  "helpdesk",
  "gw6",
  "gopher",
  "flash",
  "earth",
  "eagle",
  "devel",
  "demo",
  "cs",
  "b2",
  "athena",
  "apache",
  "www-ipv6",
  "web01",
  "voyager",
  "vega",
  "turtle",
  "tftp",
  "subversion",
  "start",
  "solaris",
  "so-0-1-0",
  "shop",
  "sam",
  "proxy2",
  "openbsd",
  "n",
  "mp3",
  "mercury",
  "log",
  "l0",
  "isis",
  "irssi",
  "if-10-0-0",
  "hydra",
  "gauss",
  "gaia",
  "fw",
  "firewall",
  "europa",
  "dl",
  "db1",
  "cms",
  "chronos",
  "charon",
  "apple",
  "u",
  "the",
  "temp",
  "t",
  "security",
  "resolver1",
  "r00",
  "po-2",
  "panda",
  "packages",
  "orion",
  "music",
  "members",
  "lo-1",
  "listserv",
  "listes",
  "leo",
  "laptop",
  "http",
  "g",
  "fox",
  "fax",
  "epp",
  "drupal",
  "dns01",
  "dc",
  "crm",
  "console",
  "ch",
  "cert",
  "c0",
  "bugzilla",
  "blue",
  "blade",
  "b0",
  "auth",
  "atlantis",
  "ar01",
  "apps",
  "zebra",
  "web3",
  "video6",
  "v6gw",
  "upload",
  "traffic",
  "tiger",
  "squid",
  "spam",
  "sigma",
  "sh",
  "sftp",
  "sf",
  "saturn",
  "s2",
  "rwhois",
  "red",
  "public",
  "photos",
  "phobos",
  "pegasus",
  "p",
  "omega",
  "nsv6",
  "ns11",
  "nfs",
  "newton",
  "neon",
  "mordor",
  "map",
  "mailserver",
  "lo0",
  "lisa",
  "j",
  "it",
  "io",
  "im",
  "hera",
  "go",
  "ge-0",
  "fw1",
  "events",
  "eth0",
  "edu",
  "echo",
  "dnscache1",
  "dns0",
  "desktop",
  "cricket",
  "cc",
  "bt",
  "bob",
  "black",
  "bender",
  "bart",
  "avalon",
  "ares",
  "abc",
  "a2",
  "a0",
  "1",
  "0",
  "wlan",
  "wireless",
  "vlad",
  "uucp",
  "update",
  "te-2-2",
  "te-2-1",
  "te-1-2",
  "statistics",
  "sp",
  "so-2-0-0",
  "snoopy",
  "silver",
  "sharepoint",
  "server2",
  "server1",
  "resolver2",
  "r2",
  "prometheus",
  "printer",
  "pop3s",
  "po-1",
  "peach",
  "pc",
  "oscar",
  "openvpn",
  "online",
  "nscache1",
  "neptune",
  "mx01",
  "moon",
  "miranda",
  "member",
  "me",
  "maxwell",
  "mailtest",
  "kdc1",
  "ircd",
  "ipv6gw",
  "ice",
  "hq",
  "homer",
  "gw1",
  "gold",
  "fred",
  "frank",
  "falcon",
  "extranet",
  "enigma",
  "downloads",
  "dns4",
  "directory",
  "dione",
  "defiant",
  "cr2",
  "cr1",
  "core",
  "charlie",
  "cat",
  "cas",
  "cam",
  "billing",
  "banana",
  "asterix",
  "antares",
  "ae-2",
  "aaa",
  "2",
  "ws",
  "webserver",
  "webdev",
  "webcast",
  "virtual",
  "vc",
  "uk",
  "tt",
  "ts1",
  "trinity",
  "training",
  "tom",
  "tm",
  "tech",
  "te-1-3",
  "submission",
  "store",
  "storage",
  "sol",
  "skynet",
  "relay2",
  "r",
  "posta",
  "pics",
  "panoramix",
  "ox",
  "open",
  "oberon",
  "nsa",
  "ns-ext",
  "nm",
  "neptun",
  "mm",
  "mike",
  "maps",
  "logger",
  "kk",
  "kepler",
  "kb",
  "k",
  "java",
  "intern",
  "hyperion",
  "gk",
  "gemini",
  "gatekeeper",
  "gamma",
  "ex",
  "eve",
  "eng",
  "dns02",
  "delta",
  "centos",
  "callisto",
  "allen",
  "agent",
  "adsl",
  "ac",
  "z",
  "wp",
  "wm",
  "webservices",
  "vox",
  "vlan2",
  "vl100",
  "vista",
  "vab2-core-1",
  "usenet",
  "us",
  "up",
  "unix",
  "tp",
  "titania",
  "thor",
  "tb",
  "tarsier",
  "spock",
  "smtp3",
  "sixxs-gw",
  "scotty",
  "rtr",
  "rt2",
  "rp",
  "rose",
  "robert",
  "rm",
  "ripe",
  "resolv1",
  "research",
  "pub",
  "proxy1",
  "pptp",
  "pos1-0",
  "pictures",
  "pgp",
  "pc1",
  "partner",
  "papa",
  "ops",
  "ns03",
  "no",
  "netlab",
  "mx03",
  "mx02",
  "ml",
  "marvin",
  "management",
  "manage",
  "mailing",
  "lu",
  "london",
  "loki",
  "logs",
  "lim-core-1",
  "lc",
  "king",
  "iris",
  "ipv4",
  "ids",
  "hotel",
  "hobbes",
  "hh",
  "hg",
  "ha",
  "gw01",
  "guest",
  "gandalf",
  "galatea",
  "fry",
  "foxtrot",
  "fe0-0",
  "fe",
  "es",
  "eprints",
  "en",
  "em",
  "ds",
  "dnscache2",
  "dict",
  "dh",
  "de",
  "customer",
  "cp",
  "correo",
  "core1",
  "code",
  "cisco2",
  "chicago",
  "cgi",
  "casper",
  "calypso",
  "build",
  "bug",
  "bt6",
  "bnc",
  "be",
  "app",
  "ap",
  "ae-0",
  "aa",
  "zulu",
  "yankee",
  "y",
  "www-v6",
  "www-3",
  "www-2",
  "www-1",
  "wins",
  "windows",
  "websites",
  "webservice",
  "web03",
  "w1",
  "vm",
  "ve1",
  "vab-core-1",
  "v6www",
  "uranus",
  "ur04",
  "updates",
  "telnet",
  "tau",
  "tao",
  "tango",
  "system",
  "sw-core1",
  "stock",
  "stage",
  "srv02",
  "src",
  "squirrel",
  "spider",
  "snail",
  "smtp-out",
  "slackware",
  "sl",
  "se",
  "scanner",
  "sc",
  "sara",
  "sap",
  "sandbox",
  "sa",
  "res1",
  "remote",
  "register",
  "redhat",
  "rc",
  "qa",
  "q",
  "puck",
  "ps",
  "pm",
  "phone",
  "phi",
  "pe",
  "pan",
  "page",
  "owa",
  "oracle",
  "oa",
  "null",
  "nss",
  "nscache",
  "nsauth1",
  "network",
  "name",
  "na",
  "mysql1",
  "mr",
  "moria",
  "mickey",
  "meta",
  "max",
  "mailin",
  "lotus",
  "local",
  "lo0-0",
  "learn",
  "lan",
  "kst-core-1",
  "jobs",
  "jg",
  "ix-2-2",
  "ix",
  "is",
  "internet",
  "int",
  "inferno",
  "img",
  "imap4",
  "ik",
  "if-0-0-0",
  "ict",
  "hp",
  "hotspot",
  "host",
  "helene",
  "he",
  "hal",
  "gw2",
  "guide",
  "green",
  "golf",
  "gh",
  "gc",
  "flow",
  "finger",
  "fido",
  "fi",
  "exeter",
  "exchange",
  "eth1",
  "et",
  "dsl",
  "diana",
  "dell",
  "decix",
  "conf",
  "cn",
  "clyde",
  "client",
  "ci",
  "chris",
  "ce",
  "catalog",
  "broadcast",
  "brain",
  "bot",
  "backups",
  "b1",
  "atom",
  "as",
  "ar02",
  "apply",
  "ams-core-1",
  "amanda",
  "ak",
  "agenda",
  "adns1",
  "access",
  "a20",
  "6net",
  "6",
  "3",
  "blog6",
  "ipv6-router",
  "www-6",
  "wwwipv6",
  "wwwv6",
  ""
};

char *sub_large[] = {
  "www",
  "mail",
  "ftp",
  "pop",
  "ipv6",
  "smtp",
  "ns1",
  "webmail",
  "ns2",
  "sql",
  "localhost",
  "ns",
  "imap",
  "ntp",
  "www6",
  "ns3",
  "irc",
  "pop3",
  "wiki",
  "news",
  "dns",
  "jabber",
  "blog",
  "svn",
  "www2",
  "ns4",
  "test",
  "dns2",
  "proxy",
  "mirror",
  "ldap",
  "time",
  "ntp1",
  "lists",
  "mx",
  "ntp2",
  "web",
  "mx1",
  "forum",
  "nagios",
  "ns0",
  "ns6",
  "v6",
  "irc6",
  "noc",
  "debian",
  "cvs",
  "gw",
  "admin",
  "mailhost",
  "home",
  "dev",
  "backup",
  "mx2",
  "sip",
  "ns5",
  "mrtg",
  "git",
  "dns1",
  "vpn",
  "sslvpn",
  "ssl-vpn",
  "lg",
  "whois",
  "mail2",
  "monitor",
  "voip",
  "stats",
  "www1",
  "intranet",
  "rt",
  "portal",
  "6to4",
  "www3",
  "ssh",
  "ns02",
  "mysql",
  "rsync",
  "relay",
  "gallery",
  "tv",
  "static",
  "router",
  "db",
  "login",
  "ftp1",
  "new",
  "mail1",
  "a",
  "mirrors",
  "media",
  "mail6",
  "loghost",
  "freebsd",
  "secure",
  "ftp2",
  "conference",
  "support",
  "ip6",
  "users",
  "ca",
  "weblog",
  "video",
  "my",
  "beta",
  "radius",
  "m",
  "cache",
  "wap",
  "ip6test",
  "ipv6test",
  "6test",
  "test6",
  "testip6",
  "testipv6",
  "www6test",
  "test6www",
  "wwwtest6",
  "ubuntu",
  "syslog",
  "shell",
  "search",
  "ip",
  "images",
  "wpad",
  "ur01",
  "ns7",
  "munin",
  "mobile",
  "linux",
  "ldap2",
  "b",
  "zeus",
  "radio",
  "loopback0",
  "info",
  "gate",
  "chat",
  "calendar",
  "stream",
  "smtp1",
  "service",
  "server",
  "radius2",
  "radius1",
  "old",
  "hosting",
  "bbs",
  "ns01",
  "net",
  "mail3",
  "c",
  "tracker",
  "ntp0",
  "nic",
  "mx0",
  "kerberos",
  "ftp6",
  "bbs6",
  "x",
  "staff",
  "smokeping",
  "nntp",
  "nms",
  "ldap1",
  "idp",
  "ftp3",
  "files",
  "alpha",
  "ad",
  "web1",
  "ur02",
  "tunnel",
  "tools",
  "stat",
  "sixxs",
  "resolver",
  "photo",
  "newsfeed",
  "moodle",
  "lab",
  "i",
  "gentoo",
  "download",
  "dns3",
  "d",
  "bugs",
  "api",
  "alice",
  "staging",
  "sirius",
  "services",
  "s",
  "rss",
  "ra",
  "php",
  "phoenix",
  "monitoring",
  "master",
  "fs",
  "data",
  "blogs",
  "web2",
  "streaming",
  "pluto",
  "people",
  "orange",
  "iptv",
  "hermes",
  "forums",
  "enterprise",
  "webstats",
  "webcam",
  "ssl",
  "s1",
  "r01",
  "mx6",
  "mx3",
  "merlin",
  "live",
  "lib",
  "janus",
  "iphone",
  "imaps",
  "help",
  "hades",
  "email",
  "doc",
  "dhcp",
  "venus",
  "turing",
  "ticket",
  "sun",
  "root",
  "projects",
  "post",
  "pki",
  "pbx",
  "office",
  "ns10",
  "mars",
  "library",
  "labs",
  "jupiter",
  "id",
  "gateway",
  "f",
  "efnet",
  "e",
  "dragon",
  "docs",
  "cisco",
  "bb",
  "autodiscover",
  "atlas",
  "ae-1",
  "win",
  "w",
  "v",
  "user",
  "ts",
  "titan",
  "teredo",
  "software",
  "sms",
  "six",
  "r02",
  "project",
  "ms",
  "mon",
  "keyserver",
  "ipv6-gw",
  "internal",
  "helpdesk",
  "gw6",
  "gopher",
  "flash",
  "earth",
  "eagle",
  "devel",
  "demo",
  "cs",
  "b2",
  "athena",
  "apache",
  "www-ipv6",
  "web01",
  "voyager",
  "vega",
  "turtle",
  "tftp",
  "subversion",
  "start",
  "solaris",
  "so-0-1-0",
  "shop",
  "sam",
  "proxy2",
  "openbsd",
  "n",
  "mp3",
  "mercury",
  "log",
  "l0",
  "isis",
  "irssi",
  "if-10-0-0",
  "hydra",
  "gauss",
  "gaia",
  "fw",
  "firewall",
  "europa",
  "dl",
  "db1",
  "cms",
  "chronos",
  "charon",
  "apple",
  "u",
  "the",
  "temp",
  "t",
  "security",
  "resolver1",
  "r00",
  "po-2",
  "panda",
  "packages",
  "orion",
  "music",
  "members",
  "lo-1",
  "listserv",
  "listes",
  "leo",
  "laptop",
  "http",
  "g",
  "fox",
  "fax",
  "epp",
  "drupal",
  "dns01",
  "dc",
  "crm",
  "console",
  "ch",
  "cert",
  "c0",
  "bugzilla",
  "blue",
  "blade",
  "b0",
  "auth",
  "atlantis",
  "ar01",
  "apps",
  "zebra",
  "web3",
  "video6",
  "v6gw",
  "upload",
  "traffic",
  "tiger",
  "squid",
  "spam",
  "sigma",
  "sh",
  "sftp",
  "sf",
  "saturn",
  "s2",
  "rwhois",
  "red",
  "public",
  "photos",
  "phobos",
  "pegasus",
  "p",
  "omega",
  "nsv6",
  "ns11",
  "nfs",
  "newton",
  "neon",
  "mordor",
  "map",
  "mailserver",
  "lo0",
  "lisa",
  "j",
  "it",
  "io",
  "im",
  "hera",
  "go",
  "ge-0",
  "fw1",
  "events",
  "eth0",
  "edu",
  "echo",
  "dnscache1",
  "dns0",
  "desktop",
  "cricket",
  "cc",
  "bt",
  "bob",
  "black",
  "bender",
  "bart",
  "avalon",
  "ares",
  "abc",
  "a2",
  "a0",
  "1",
  "0",
  "wlan",
  "wireless",
  "vlad",
  "uucp",
  "update",
  "te-2-2",
  "te-2-1",
  "te-1-2",
  "statistics",
  "sp",
  "so-2-0-0",
  "snoopy",
  "silver",
  "sharepoint",
  "server2",
  "server1",
  "resolver2",
  "r2",
  "prometheus",
  "printer",
  "pop3s",
  "po-1",
  "peach",
  "pc",
  "oscar",
  "openvpn",
  "online",
  "nscache1",
  "neptune",
  "mx01",
  "moon",
  "miranda",
  "member",
  "me",
  "maxwell",
  "mailtest",
  "kdc1",
  "ircd",
  "ipv6gw",
  "ice",
  "hq",
  "homer",
  "gw1",
  "gold",
  "fred",
  "frank",
  "falcon",
  "extranet",
  "enigma",
  "downloads",
  "dns4",
  "directory",
  "dione",
  "defiant",
  "cr2",
  "cr1",
  "core",
  "charlie",
  "cat",
  "cas",
  "cam",
  "billing",
  "banana",
  "asterix",
  "antares",
  "ae-2",
  "aaa",
  "2",
  "ws",
  "webserver",
  "webdev",
  "webcast",
  "virtual",
  "vc",
  "uk",
  "tt",
  "ts1",
  "trinity",
  "training",
  "tom",
  "tm",
  "tech",
  "te-1-3",
  "submission",
  "store",
  "storage",
  "sol",
  "skynet",
  "relay2",
  "r",
  "posta",
  "pics",
  "panoramix",
  "ox",
  "open",
  "oberon",
  "nsa",
  "ns-ext",
  "nm",
  "neptun",
  "mm",
  "mike",
  "maps",
  "logger",
  "kk",
  "kepler",
  "kb",
  "k",
  "java",
  "intern",
  "hyperion",
  "gk",
  "gemini",
  "gatekeeper",
  "gamma",
  "ex",
  "eve",
  "eng",
  "dns02",
  "delta",
  "centos",
  "callisto",
  "allen",
  "agent",
  "adsl",
  "ac",
  "z",
  "wp",
  "wm",
  "webservices",
  "vox",
  "vlan2",
  "vl100",
  "vista",
  "vab2-core-1",
  "usenet",
  "us",
  "up",
  "unix",
  "tp",
  "titania",
  "thor",
  "tb",
  "tarsier",
  "spock",
  "smtp3",
  "sixxs-gw",
  "scotty",
  "rtr",
  "rt2",
  "rp",
  "rose",
  "robert",
  "rm",
  "ripe",
  "resolv1",
  "research",
  "pub",
  "proxy1",
  "pptp",
  "pos1-0",
  "pictures",
  "pgp",
  "pc1",
  "partner",
  "papa",
  "ops",
  "ns03",
  "no",
  "netlab",
  "mx03",
  "mx02",
  "ml",
  "marvin",
  "management",
  "manage",
  "mailing",
  "lu",
  "london",
  "loki",
  "logs",
  "lim-core-1",
  "lc",
  "king",
  "iris",
  "ipv4",
  "ids",
  "hotel",
  "hobbes",
  "hh",
  "hg",
  "ha",
  "gw01",
  "guest",
  "gandalf",
  "galatea",
  "fry",
  "foxtrot",
  "fe0-0",
  "fe",
  "es",
  "eprints",
  "en",
  "em",
  "ds",
  "dnscache2",
  "dict",
  "dh",
  "de",
  "customer",
  "cp",
  "correo",
  "core1",
  "code",
  "cisco2",
  "chicago",
  "cgi",
  "casper",
  "calypso",
  "build",
  "bug",
  "bt6",
  "bnc",
  "be",
  "app",
  "ap",
  "ae-0",
  "aa",
  "zulu",
  "yankee",
  "y",
  "www-v6",
  "www-3",
  "www-2",
  "www-1",
  "wins",
  "windows",
  "websites",
  "webservice",
  "web03",
  "w1",
  "vm",
  "ve1",
  "vab-core-1",
  "v6www",
  "uranus",
  "ur04",
  "updates",
  "telnet",
  "tau",
  "tao",
  "tango",
  "system",
  "sw-core1",
  "stock",
  "stage",
  "srv02",
  "src",
  "squirrel",
  "spider",
  "snail",
  "smtp-out",
  "slackware",
  "sl",
  "se",
  "scanner",
  "sc",
  "sara",
  "sap",
  "sandbox",
  "sa",
  "res1",
  "remote",
  "register",
  "redhat",
  "rc",
  "qa",
  "q",
  "puck",
  "ps",
  "pm",
  "phone",
  "phi",
  "pe",
  "pan",
  "page",
  "owa",
  "oracle",
  "oa",
  "null",
  "nss",
  "nscache",
  "nsauth1",
  "network",
  "name",
  "na",
  "mysql1",
  "mr",
  "moria",
  "mickey",
  "meta",
  "max",
  "mailin",
  "lotus",
  "local",
  "lo0-0",
  "learn",
  "lan",
  "kst-core-1",
  "jobs",
  "jg",
  "ix-2-2",
  "ix",
  "is",
  "internet",
  "int",
  "inferno",
  "img",
  "imap4",
  "ik",
  "if-0-0-0",
  "ict",
  "hp",
  "hotspot",
  "host",
  "helene",
  "he",
  "hal",
  "gw2",
  "guide",
  "green",
  "golf",
  "gh",
  "gc",
  "flow",
  "finger",
  "fido",
  "fi",
  "exeter",
  "exchange",
  "eth1",
  "et",
  "dsl",
  "diana",
  "dell",
  "decix",
  "conf",
  "cn",
  "clyde",
  "client",
  "ci",
  "chris",
  "ce",
  "catalog",
  "broadcast",
  "brain",
  "bot",
  "backups",
  "b1",
  "atom",
  "as",
  "ar02",
  "apply",
  "ams-core-1",
  "amanda",
  "ak",
  "agenda",
  "adns1",
  "access",
  "a20",
  "6net",
  "6",
  "3",
  "zt",
  "zope",
  "zm",
  "za",
  "yp",
  "xp",
  "xml",
  "xen",
  "xe-0-2-0-0",
  "wx",
  "www03",
  "wt",
  "world",
  "work",
  "wg",
  "welcome",
  "webster",
  "websrv",
  "webmin",
  "webcache",
  "webadmin",
  "web02",
  "wan",
  "vz",
  "vt",
  "vs",
  "vo",
  "vlan1",
  "vk",
  "vip",
  "violet",
  "videos",
  "ve",
  "vault",
  "vaak",
  "uu",
  "usa",
  "ur03",
  "union",
  "uni",
  "ui",
  "tx",
  "tw",
  "tunnel2",
  "tr",
  "tool",
  "toad",
  "to",
  "tk",
  "theta",
  "testing",
  "testbed",
  "terminal",
  "team",
  "te-3-1",
  "tc",
  "talk",
  "ta",
  "sysadmin",
  "switch",
  "submit",
  "su",
  "ssc",
  "sr",
  "sql1",
  "sprint",
  "so-0-0-1",
  "so-0-0-0",
  "sk",
  "silc",
  "shell1",
  "services1",
  "server3",
  "sb",
  "ru",
  "ro",
  "rn",
  "reg",
  "rd",
  "raptor",
  "quark",
  "qp",
  "proton",
  "privat",
  "printserver",
  "press",
  "pq",
  "pop2",
  "pl",
  "pix",
  "picard",
  "pd",
  "pc4",
  "partners",
  "paris",
  "pages",
  "oz",
  "operations",
  "nscache2",
  "november",
  "nl",
  "ni",
  "netstat",
  "netapp",
  "nc",
  "nameserver",
  "mv",
  "multimedia",
  "mu",
  "movies",
  "moscow",
  "mon2",
  "mon1",
  "mk",
  "mi",
  "md",
  "mb",
  "mary",
  "mailgate",
  "mac",
  "luke",
  "lt",
  "lorien",
  "link",
  "lima",
  "lan-gate",
  "lambda",
  "ks",
  "kernel",
  "itchy",
  "ipv6forum",
  "ipv6cam",
  "ipsec",
  "invalid",
  "international",
  "install",
  "if",
  "ie",
  "icons",
  "iax",
  "hu",
  "hs",
  "hm",
  "hello",
  "helium",
  "hc",
  "hammer",
  "h",
  "gw3",
  "gs",
  "groups",
  "gps",
  "gm",
  "gigabitethernet0",
  "germany",
  "geb",
  "ge-0-0-0-0",
  "galeria",
  "fx",
  "fw01",
  "fun",
  "fr",
  "fotos",
  "fm",
  "finance",
  "fileserver",
  "fg",
  "feeds",
  "fe2-0",
  "fc",
  "fa",
  "extern",
  "eu",
  "eth2",
  "er",
  "ep",
  "enum",
  "enable",
  "eh",
  "ee",
  "ec",
  "dx",
  "dr",
  "doom",
  "domino",
  "domains",
  "domain",
  "do",
  "dns03",
  "dk",
  "dist",
  "discovery",
  "disco",
  "dirac",
  "developers",
  "des",
  "depot",
  "db0",
  "cz",
  "cv",
  "cq",
  "corpmail",
  "corp",
  "corona",
  "cook",
  "contact",
  "com",
  "co",
  "cm",
  "charlotte",
  "cfengine",
  "cb",
  "by",
  "bw",
  "bsd",
  "br2",
  "br",
  "boston",
  "blackboard",
  "biblioteca",
  "bg",
  "bd",
  "bb1",
  "baker",
  "backbone",
  "b10",
  "az",
  "aw",
  "av",
  "auth2",
  "auth03",
  "auth02",
  "auth01",
  "au",
  "atw",
  "at",
  "argos",
  "app1",
  "ao",
  "antivirus",
  "anonsvn",
  "aix",
  "ag",
  "ads",
  "acid",
  "achilles",
  "ab",
  "a01",
  "8",
  "7",
  "5",
  "4",
  "31337",
  "zw",
  "zu",
  "zq",
  "zo",
  "zk",
  "zc",
  "yv",
  "ys",
  "young",
  "yn",
  "yl",
  "yellow",
  "xy",
  "xx",
  "xtel",
  "xt",
  "xs",
  "xo",
  "xk",
  "xj",
  "xi",
  "xdmcp",
  "xd",
  "xc",
  "xb",
  "x-ray",
  "wwwdev",
  "www01",
  "ws3",
  "ws2",
  "wq",
  "wordpress",
  "wl",
  "wk",
  "winxp",
  "winproxy",
  "windowsxp",
  "win2k8",
  "win2k",
  "win2008",
  "wi",
  "wh1",
  "wh",
  "west",
  "webserv",
  "webmaster",
  "webhelp",
  "webct",
  "web0",
  "wc",
  "washington",
  "warlord",
  "wallet",
  "w2",
  "w-04",
  "vw",
  "vr",
  "vpn1",
  "voice",
  "vnc",
  "vmm",
  "vl102",
  "vl10",
  "viking",
  "victor",
  "ve8",
  "uz",
  "uw",
  "ut",
  "ur",
  "upsilon",
  "unknown",
  "uniform",
  "undernet-gw",
  "tunnelbroker",
  "tu0",
  "tour",
  "tomocha",
  "tj",
  "testsite",
  "terror",
  "teredo-relay",
  "teredo-gw",
  "telephone",
  "techsupport",
  "sz",
  "sydney",
  "sw1",
  "sw01",
  "sw0",
  "svr02",
  "svr01",
  "sv",
  "superman",
  "sun1",
  "sun02",
  "sun01",
  "studio",
  "splunk",
  "spl",
  "spiderman",
  "spain",
  "source",
  "solutions",
  "snmp-trap",
  "smc",
  "sm",
  "sj",
  "site",
  "sg",
  "servers",
  "server6",
  "server5",
  "server4",
  "sec",
  "search6",
  "rz",
  "rv",
  "rr",
  "router2",
  "romeo",
  "ris",
  "reseller",
  "res2",
  "releases",
  "relay02",
  "relay01",
  "redirect2",
  "read",
  "rcs",
  "queen",
  "quebec",
  "quake",
  "pt",
  "prod",
  "priv",
  "print",
  "preprod",
  "prensa",
  "posix",
  "po1",
  "po",
  "pm1",
  "pk",
  "pironet",
  "pi",
  "pf",
  "pdc",
  "pda",
  "pc8",
  "pc6",
  "pc5",
  "pc3",
  "pc2",
  "pa",
  "outlook",
  "out",
  "os",
  "op",
  "ojp-apply",
  "oh",
  "of",
  "oc48-pos9-0",
  "oc",
  "ob",
  "nx",
  "ns15",
  "nokia",
  "node",
  "nn",
  "newyork",
  "newsfeeds",
  "nevada",
  "nessus",
  "neo",
  "ne",
  "nds",
  "nd",
  "nb",
  "nat",
  "mz",
  "mta",
  "mpeg",
  "mp",
  "monitor01",
  "mj",
  "minerva",
  "messenger",
  "mc",
  "marketing",
  "mailgw3",
  "ma",
  "m-net",
  "ls",
  "logging",
  "lo",
  "lm",
  "lj",
  "listserver",
  "li",
  "lenny",
  "laforge",
  "la",
  "kz",
  "km",
  "kl",
  "kf",
  "ka",
  "jw",
  "juliet",
  "jp",
  "jo",
  "issues",
  "isaiah",
  "ireland",
  "ipx",
  "ipv6-router",
  "investor",
  "internet2",
  "inside",
  "ins2",
  "inc",
  "illusion",
  "if-2-0-0",
  "icecube",
  "ic",
  "ibm",
  "hub",
  "https",
  "houston",
  "host3",
  "honeypot",
  "homepage",
  "hobby-gw",
  "hk",
  "hidden",
  "hi",
  "hercules",
  "hd",
  "gz",
  "gx",
  "gt",
  "group",
  "gr",
  "gp",
  "gigabitethernet1",
  "galerie",
  "fw1-gw",
  "ftp0",
  "front",
  "freemail",
  "france",
  "fp",
  "foto",
  "fl",
  "fa-0-0",
  "f5",
  "eunomia",
  "eta",
  "erp",
  "eo",
  "engineering",
  "enc",
  "ed",
  "dynamic",
  "dyn",
  "dy",
  "dt",
  "dns00",
  "dns-2",
  "dn",
  "dmz",
  "disk",
  "disc",
  "dino",
  "digital",
  "dial",
  "development",
  "develop",
  "deve",
  "dev01",
  "design",
  "demon",
  "default",
  "de-cix",
  "db2",
  "database",
  "d1-0",
  "cw",
  "cr3",
  "content",
  "constellation",
  "compaq",
  "community",
  "colorado",
  "colo0-gw",
  "cocoa",
  "cluster",
  "club",
  "cleveland",
  "class",
  "cisco1",
  "chimera",
  "chi",
  "cg",
  "certificates",
  "cd",
  "careers",
  "canal",
  "call",
  "cafe",
  "bridge",
  "bravo",
  "bp",
  "bo",
  "blog6",
  "blacksun",
  "blackberry",
  "bl",
  "biz",
  "bip1-gw",
  "biff",
  "bi",
  "bgp",
  "ba",
  "b02",
  "avmail",
  "auto",
  "atlanta",
  "arizona",
  "ari",
  "arcnet6",
  "arachne",
  "ar2",
  "aq",
  "announce",
  "albuquerque",
  "alaska",
  "al",
  "ajax",
  "adam",
  "accounts",
  "accounting",
  "aaaa",
  "a21",
  "a02",
  "9",
  "20",
  "17",
  "16",
  "15",
  "14",
  "13",
  "10",
  "03",
  "www-6",
  "wwwipv6",
  "wwwv6",
  "auth0",
  "auth00",
  "dns6",
  "gate1",
  "gw-ipv6",
  "ntp3",
  "rns2",
  "sec1",
  "vl-6",
  "vlan-100",
  "vlan100",
  "www-v6v4",
  "dds",
  "vds",
  ""
};

char *sub_xtreme[] = {
  "0",
  "01",
  "02",
  "03",
  "1",
  "10",
  "10gigabitethernet1-2",
  "11",
  "12",
  "13",
  "14",
  "15",
  "16",
  "17",
  "18",
  "19",
  "1g-bge0",
  "1g-eth0",
  "2",
  "20",
  "3",
  "31337",
  "32983d48de4470",
  "3com",
  "4",
  "42",
  "5",
  "6",
  "6b1",
  "6net",
  "6to4",
  "7",
  "8",
  "9",
  "ILMI",
  "a",
  "ip6test",
  "ipv6test",
  "6test",
  "test6",
  "testip6",
  "testipv6",
  "www6test",
  "test6www",
  "wwwtest6",
  "a.auth-ns",
  "a0",
  "a01",
  "a02",
  "a1",
  "a2",
  "a20",
  "a21",
  "aa",
  "aaa",
  "aaaa",
  "ab",
  "abc",
  "about",
  "ac",
  "academ",
  "academico",
  "acceso",
  "access",
  "accounting",
  "accounts",
  "achilles",
  "acid",
  "activestat",
  "ad",
  "adam",
  "adkit",
  "admin",
  "administracion",
  "administrador",
  "administrator",
  "administrators",
  "admins",
  "adns1",
  "ads",
  "adserver",
  "adsl",
  "ae",
  "ae-0",
  "ae-1",
  "ae-2",
  "af",
  "affiliate",
  "affiliates",
  "afiliados",
  "afs3-bos",
  "afs3-callback",
  "afs3-errors",
  "afs3-fileserver",
  "afs3-kaserver",
  "afs3-prserver",
  "afs3-rmtsys",
  "afs3-update",
  "afs3-vlserver",
  "afs3-volser",
  "ag",
  "agenda",
  "agent",
  "ah",
  "ai",
  "aix",
  "aj",
  "ajax",
  "ak",
  "akamai",
  "al",
  "alabama",
  "alaska",
  "albuquerque",
  "alerts",
  "alice",
  "allen",
  "alpha",
  "alterwind",
  "am",
  "amanda",
  "amandaidx",
  "amarillo",
  "americas",
  "ams-core-1",
  "an",
  "anaheim",
  "analyzer",
  "announce",
  "announcements",
  "anonsvn",
  "anonymous",
  "antares",
  "antivirus",
  "ao",
  "ap",
  "apache",
  "api",
  "apollo",
  "app",
  "app01",
  "app1",
  "apple",
  "application",
  "applications",
  "apply",
  "apps",
  "appserver",
  "aq",
  "ar",
  "ar01",
  "ar02",
  "ar2",
  "arachne",
  "archie",
  "archivos",
  "arcnet6",
  "arcsight",
  "ares",
  "argentina",
  "argos",
  "ari",
  "arizona",
  "arkansas",
  "arlington",
  "as",
  "as-0",
  "as-2",
  "as400",
  "asia",
  "asp",
  "asterix",
  "at",
  "athena",
  "atlanta",
  "atlantis",
  "atlas",
  "atom",
  "att",
  "atw",
  "atw6",
  "au",
  "auction",
  "aula",
  "aulas",
  "austin",
  "auth",
  "auth-ns",
  "auth01",
  "auth02",
  "auth03",
  "auth1",
  "auth2",
  "auto",
  "autodiscover",
  "autorun",
  "av",
  "avalon",
  "avmail",
  "aw",
  "ax",
  "ay",
  "ayuda",
  "az",
  "b",
  "b.auth-ns",
  "b0",
  "b01",
  "b02",
  "b1",
  "b10",
  "b2",
  "b2b",
  "b2c",
  "ba",
  "back",
  "backbone",
  "backend",
  "backup",
  "backups",
  "baker",
  "bakersfield",
  "balance",
  "balancer",
  "baltimore",
  "banana",
  "banking",
  "bart",
  "bayarea",
  "bb",
  "bb1",
  "bbdd",
  "bbs",
  "bbs6",
  "bc",
  "bce1",
  "bd",
  "bdc",
  "be",
  "bea",
  "bender",
  "beta",
  "bf",
  "bg",
  "bgp",
  "bgpd",
  "bh",
  "bi",
  "biblioteca",
  "biff",
  "billing",
  "bip1-gw",
  "biz",
  "biztalk",
  "bj",
  "bk",
  "bl",
  "black",
  "blackberry",
  "blackboard",
  "blackhole",
  "blacksun",
  "blade",
  "blazing",
  "blog",
  "blog6",
  "blogs",
  "blue",
  "bm",
  "bn",
  "bnc",
  "bo",
  "bob",
  "bof",
  "boise",
  "bolsa",
  "bootpc",
  "bootps",
  "border",
  "boston",
  "bot",
  "boulder",
  "boy",
  "bp",
  "bpcd",
  "bpdbm",
  "bprd",
  "bq",
  "br",
  "br0",
  "br2",
  "br3",
  "brain",
  "bravo",
  "brazil",
  "bridge",
  "britian",
  "broadcast",
  "broker",
  "bronze",
  "brown",
  "bs",
  "bsd",
  "bsd0",
  "bsd01",
  "bsd02",
  "bsd1",
  "bsd2",
  "bt",
  "bt6",
  "bu",
  "bug",
  "buggalo",
  "bugs",
  "bugzilla",
  "build",
  "bulletins",
  "burn",
  "burner",
  "buscador",
  "buy",
  "bv",
  "bw",
  "bwm",
  "bx",
  "by",
  "bz",
  "c",
  "c.auth-ns",
  "c0",
  "ca",
  "cache",
  "cafe",
  "calendar",
  "california",
  "call",
  "callisto",
  "calvin",
  "calypso",
  "cam",
  "canada",
  "canal",
  "canna",
  "canon",
  "careers",
  "carro",
  "cart",
  "cas",
  "casper",
  "casse",
  "cat",
  "catalog",
  "catalogo",
  "catalogue",
  "cb",
  "cc",
  "cd",
  "cd1",
  "cdburner",
  "cdn",
  "ce",
  "centos",
  "cert",
  "certificates",
  "certify",
  "certserv",
  "certsrv",
  "cf",
  "cfengine",
  "cfinger",
  "cg",
  "cgi",
  "ch",
  "channel",
  "channels",
  "chargen",
  "charlie",
  "charlotte",
  "charon",
  "chat",
  "chats",
  "chatserver",
  "check",
  "checkpoint",
  "chi",
  "chicago",
  "chimera",
  "chris",
  "chronos",
  "ci",
  "cims",
  "cincinnati",
  "cisco",
  "cisco1",
  "cisco2",
  "citrix",
  "cj",
  "ck",
  "cl",
  "class",
  "classes",
  "classifieds",
  "classroom",
  "clearcase",
  "cleveland",
  "clicktrack",
  "client",
  "clientes",
  "clientrouter",
  "clients",
  "cll",
  "club",
  "clubs",
  "cluster",
  "clusters",
  "clyde",
  "cm",
  "cmail",
  "cmip-agent",
  "cmip-man",
  "cms",
  "cn",
  "cns1",
  "cns2",
  "co",
  "cocoa",
  "codasrv",
  "codasrv-se",
  "code",
  "coldfusion",
  "colo0-gw",
  "colombus",
  "colorado",
  "columbus",
  "com",
  "comment",
  "commerce",
  "commerceserver",
  "communigate",
  "community",
  "compaq",
  "compras",
  "con",
  "concentrator",
  "conf",
  "conference",
  "conferencing",
  "confidential",
  "connect",
  "connecticut",
  "consola",
  "console",
  "constellation",
  "consult",
  "consultant",
  "consultants",
  "consulting",
  "consumer",
  "contact",
  "content",
  "contracts",
  "controller",
  "cook",
  "core",
  "core0",
  "core01",
  "core1",
  "corona",
  "corp",
  "corpmail",
  "corporate",
  "correo",
  "correoweb",
  "cortafuegos",
  "counterstrike",
  "courier",
  "courses",
  "cp",
  "cpanel",
  "cph-cr1",
  "cq",
  "cr",
  "cr1",
  "cr2",
  "cr3",
  "cricket",
  "crm",
  "crs",
  "cs",
  "cs0",
  "csg",
  "csnet-ns",
  "cso",
  "css",
  "ct",
  "cu",
  "cust",
  "cust1",
  "cust10",
  "cust100",
  "cust101",
  "cust102",
  "cust103",
  "cust104",
  "cust105",
  "cust106",
  "cust107",
  "cust108",
  "cust109",
  "cust11",
  "cust110",
  "cust111",
  "cust112",
  "cust113",
  "cust114",
  "cust115",
  "cust116",
  "cust117",
  "cust118",
  "cust119",
  "cust12",
  "cust120",
  "cust121",
  "cust122",
  "cust123",
  "cust124",
  "cust125",
  "cust126",
  "cust13",
  "cust14",
  "cust15",
  "cust16",
  "cust17",
  "cust18",
  "cust19",
  "cust2",
  "cust20",
  "cust21",
  "cust22",
  "cust23",
  "cust24",
  "cust25",
  "cust26",
  "cust27",
  "cust28",
  "cust29",
  "cust3",
  "cust30",
  "cust31",
  "cust32",
  "cust33",
  "cust34",
  "cust35",
  "cust36",
  "cust37",
  "cust38",
  "cust39",
  "cust4",
  "cust40",
  "cust41",
  "cust42",
  "cust43",
  "cust44",
  "cust45",
  "cust46",
  "cust47",
  "cust48",
  "cust49",
  "cust5",
  "cust50",
  "cust51",
  "cust52",
  "cust53",
  "cust54",
  "cust55",
  "cust56",
  "cust57",
  "cust58",
  "cust59",
  "cust6",
  "cust60",
  "cust61",
  "cust62",
  "cust63",
  "cust64",
  "cust65",
  "cust66",
  "cust67",
  "cust68",
  "cust69",
  "cust7",
  "cust70",
  "cust71",
  "cust72",
  "cust73",
  "cust74",
  "cust75",
  "cust76",
  "cust77",
  "cust78",
  "cust79",
  "cust8",
  "cust80",
  "cust81",
  "cust82",
  "cust83",
  "cust84",
  "cust85",
  "cust86",
  "cust87",
  "cust88",
  "cust89",
  "cust9",
  "cust90",
  "cust91",
  "cust92",
  "cust93",
  "cust94",
  "cust95",
  "cust96",
  "cust97",
  "cust98",
  "cust99",
  "customer",
  "customers",
  "customs",
  "cv",
  "cvs",
  "cvspserver",
  "cw",
  "cx",
  "cy",
  "cyborgs",
  "cz",
  "d",
  "d0",
  "d1-0",
  "da",
  "daap",
  "dallas",
  "data",
  "database",
  "database01",
  "database02",
  "database1",
  "database2",
  "databases",
  "datametrics",
  "datastore",
  "datatracker",
  "datos",
  "david",
  "daytime",
  "db",
  "db0",
  "db01",
  "db02",
  "db03",
  "db1",
  "db2",
  "db3",
  "dbs",
  "dc",
  "dd",
  "dds",
  "de",
  "de-cix",
  "dealers",
  "debian",
  "dec",
  "decix",
  "def",
  "default",
  "defiant",
  "delaware",
  "dell",
  "delta",
  "delta1",
  "demo",
  "demon",
  "demonstration",
  "demos",
  "demostration",
  "denver",
  "depot",
  "des",
  "desarrollo",
  "descargas",
  "design",
  "designer",
  "desktop",
  "detroit",
  "deutschland",
  "dev",
  "dev0",
  "dev01",
  "dev1",
  "deve",
  "devel",
  "develop",
  "developer",
  "developers",
  "development",
  "device",
  "devserver",
  "devsql",
  "df",
  "dg",
  "dh",
  "dhcp",
  "di",
  "dial",
  "dialup",
  "diana",
  "diary",
  "dict",
  "digital",
  "dilbert",
  "dino",
  "dione",
  "dir",
  "dirac",
  "dircproxy",
  "direct",
  "directory",
  "disc",
  "discard",
  "disco",
  "discovery",
  "discuss",
  "discussion",
  "discussions",
  "disk",
  "disney",
  "dist",
  "distcc",
  "distmp3",
  "distributer",
  "distributers",
  "dj",
  "dk",
  "dl",
  "dm",
  "dmail",
  "dmz",
  "dmz-gw",
  "dn",
  "dnews",
  "dns",
  "dns-2",
  "dns-cache1",
  "dns-cache2",
  "dns0",
  "dns00",
  "dns01",
  "dns02",
  "dns03",
  "dns1",
  "dns2",
  "dns3",
  "dns4",
  "dnscache1",
  "dnscache2",
  "do",
  "doc",
  "docs",
  "documentacion",
  "documentos",
  "domain",
  "domain-controller",
  "domaincontroller",
  "domains",
  "dominio",
  "domino",
  "dominoweb",
  "doom",
  "download",
  "downloads",
  "downtown",
  "dp",
  "dq",
  "dr",
  "draal",
  "dragon",
  "drupal",
  "ds",
  "dsl",
  "dt",
  "du",
  "dv",
  "dw",
  "dx",
  "dy",
  "dyn",
  "dynamic",
  "dynip",
  "dz",
  "e",
  "e-com",
  "e-commerce",
  "e0",
  "ea",
  "eaccess",
  "eagle",
  "earth",
  "east",
  "eb",
  "ec",
  "echo",
  "ecom",
  "ecommerce",
  "ed",
  "edi",
  "edu",
  "education",
  "edward",
  "ee",
  "ef",
  "efnet",
  "eg",
  "eh",
  "ei",
  "ej",
  "ejemplo",
  "ejemplos",
  "ek",
  "eklogin",
  "el",
  "elpaso",
  "em",
  "email",
  "employees",
  "empresa",
  "empresas",
  "en",
  "enable",
  "enbd-cstatd",
  "enbd-sstatd",
  "enc",
  "eng",
  "eng01",
  "eng1",
  "engine",
  "engineer",
  "engineering",
  "enigma",
  "enrutador",
  "enterprise",
  "enum",
  "eo",
  "ep",
  "epp",
  "eprints",
  "epsilon",
  "epzilon",
  "eq",
  "er",
  "erp",
  "es",
  "esd",
  "eservice",
  "esm",
  "espanol",
  "estadisticas",
  "esx",
  "et",
  "eta",
  "eth0",
  "eth1",
  "eth2",
  "eu",
  "eunomia",
  "europa",
  "europe",
  "ev",
  "eve",
  "eventos",
  "events",
  "ew",
  "ex",
  "example",
  "examples",
  "exchange",
  "exec",
  "exeter",
  "exit",
  "extern",
  "external",
  "extra",
  "extranet",
  "ey",
  "ez",
  "f",
  "f0-0",
  "f5",
  "fa",
  "fa-0-0",
  "falcon",
  "farm",
  "faststats",
  "fatserv",
  "fax",
  "fb",
  "fc",
  "fd",
  "fe",
  "fe0-0",
  "fe1-0",
  "fe2-0",
  "feedback",
  "feeds",
  "ff",
  "fg",
  "fh",
  "fi",
  "fido",
  "field",
  "file",
  "files",
  "fileserv",
  "fileserver",
  "filestore",
  "filter",
  "finance",
  "find",
  "finger",
  "firewall",
  "fix",
  "fixes",
  "fj",
  "fk",
  "fl",
  "flash",
  "florida",
  "flow",
  "fm",
  "fn",
  "fo",
  "font-service",
  "foobar",
  "formacion",
  "foro",
  "foros",
  "fortworth",
  "forum",
  "forums",
  "foto",
  "fotos",
  "foundry",
  "fox",
  "foxtrot",
  "fp",
  "fq",
  "fr",
  "france",
  "frank",
  "fred",
  "freebsd",
  "freebsd0",
  "freebsd01",
  "freebsd02",
  "freebsd1",
  "freebsd2",
  "freemail",
  "freeware",
  "fresno",
  "front",
  "frontdesk",
  "frox",
  "fry",
  "fs",
  "fsp",
  "ft",
  "ftb",
  "ftp",
  "ftp-",
  "ftp-data",
  "ftp0",
  "ftp1",
  "ftp2",
  "ftp3",
  "ftp6",
  "ftpd",
  "ftps",
  "ftps-data",
  "ftpserver",
  "fu",
  "fun",
  "fv",
  "fw",
  "fw-1",
  "fw0",
  "fw00",
  "fw01",
  "fw02",
  "fw03",
  "fw1",
  "fw1-gw",
  "fw2",
  "fw3",
  "fwsm",
  "fwsm0",
  "fwsm01",
  "fwsm1",
  "fx",
  "fy",
  "fz",
  "g",
  "g0-26",
  "ga",
  "gaia",
  "galatea",
  "galeria",
  "galerias",
  "galerie",
  "galleries",
  "gallery",
  "games",
  "gameserver",
  "gamma",
  "gandalf",
  "gate",
  "gatekeeper",
  "gateway",
  "gauss",
  "gb",
  "gc",
  "gd",
  "gdomap",
  "gds_db",
  "ge",
  "ge-0",
  "ge-0-0-0-0",
  "ge0",
  "ge0-1",
  "ge1",
  "ge1-0",
  "ge11",
  "ge13",
  "ge2-0",
  "geb",
  "gemini",
  "general",
  "gentoo",
  "george",
  "georgia",
  "ger",
  "germany",
  "gf",
  "gg",
  "ggz",
  "gh",
  "gi",
  "gi-0-1",
  "gi0-0",
  "gi0-1",
  "gi2-0",
  "gigabitethernet0",
  "gigabitethernet1",
  "gige-g0-1",
  "gige-gbge0",
  "gilford",
  "git",
  "gizmo",
  "gj",
  "gk",
  "gl",
  "glendale",
  "gm",
  "gmail",
  "gn",
  "gnutella-rtr",
  "gnutella-svc",
  "go",
  "gold",
  "goldmine",
  "golf",
  "gopher",
  "gp",
  "gps",
  "gpsd",
  "gq",
  "gr",
  "green",
  "group",
  "groups",
  "groupwise",
  "gs",
  "gsx",
  "gt",
  "gu",
  "guest",
  "guia",
  "guide",
  "gv",
  "gw",
  "gw01",
  "gw1",
  "gw2",
  "gw3",
  "gw6",
  "gx",
  "gy",
  "gz",
  "h",
  "ha",
  "hades",
  "hal",
  "halflife",
  "hammer",
  "haproxy",
  "has",
  "hawaii",
  "hb",
  "hc",
  "hd",
  "he",
  "helene",
  "helium",
  "helix",
  "hello",
  "help",
  "helpdesk",
  "helponline",
  "henry",
  "hera",
  "heracles",
  "hercules",
  "hermes",
  "hf",
  "hg",
  "hh",
  "hi",
  "hidden",
  "hj",
  "hk",
  "hkp",
  "hl",
  "hm",
  "hmmp-ind",
  "hn",
  "ho",
  "hobbes",
  "hobby-gw",
  "hollywood",
  "home",
  "homebase",
  "homepage",
  "homer",
  "honeypot",
  "honolulu",
  "hop",
  "host",
  "host1",
  "host3",
  "host4",
  "host5",
  "hosting",
  "hostmon",
  "hostnames",
  "hotel",
  "hotjobs",
  "hotspot",
  "houstin",
  "houston",
  "howto",
  "hp",
  "hpov",
  "hq",
  "hr",
  "hs",
  "ht",
  "http",
  "https",
  "hu",
  "hub",
  "humanresources",
  "hund",
  "hv",
  "hw",
  "hx",
  "hy",
  "hydra",
  "hylafax",
  "hyperion",
  "hypernova",
  "hz",
  "i",
  "ia",
  "ias",
  "iax",
  "ib",
  "ibm",
  "ibmdb",
  "ic",
  "ice",
  "icecube",
  "icons",
  "icpv2",
  "ict",
  "id",
  "ida",
  "idaho",
  "idp",
  "ids",
  "ie",
  "if",
  "if-0-0-0",
  "if-10-0-0",
  "if-2-0-0",
  "ig",
  "ih",
  "ii",
  "iis",
  "ij",
  "ik",
  "il",
  "illinois",
  "illusion",
  "im",
  "images",
  "imail",
  "imap",
  "imap3d",
  "imap4",
  "imapd",
  "imaps",
  "img",
  "img0",
  "img01",
  "img02",
  "imgs",
  "imogen",
  "imsp",
  "in",
  "inbound",
  "inc",
  "include",
  "incoming",
  "india",
  "indiana",
  "indianapolis",
  "inferno",
  "info",
  "informix",
  "ingreslock",
  "inmuebles",
  "ins2",
  "inside",
  "install",
  "int",
  "intern",
  "internal",
  "international",
  "internet",
  "internet2",
  "interno",
  "intl",
  "intranet",
  "invalid",
  "investor",
  "investors",
  "io",
  "iota",
  "iowa",
  "ip",
  "ip6",
  "ipad",
  "iphone",
  "iplanet",
  "ipmonitor",
  "ipod",
  "ipp",
  "iprop",
  "ipsec",
  "ipsec-gw",
  "iptv",
  "ipv4",
  "ipv6",
  "ipv6-gw",
  "ipv6-router",
  "ipv6.teredo",
  "ipv6cam",
  "ipv6forum",
  "ipv6gw",
  "ipv6tv",
  "ipx",
  "iq",
  "ir",
  "irc",
  "irc6",
  "ircd",
  "ircs",
  "ircserver",
  "ireland",
  "iris",
  "irssi",
  "irvine",
  "irving",
  "is",
  "isa",
  "isaiah",
  "isakmp",
  "isaserv",
  "isaserver",
  "isdnlog",
  "isis",
  "isisd",
  "ism",
  "iso-tsap",
  "israel",
  "issues",
  "isync",
  "it",
  "italy",
  "itchy",
  "iu",
  "iv",
  "iw",
  "ix",
  "ix-2-2",
  "iy",
  "iz",
  "j",
  "ja",
  "jabber",
  "janus",
  "japan",
  "java",
  "jb",
  "jc",
  "jd",
  "je",
  "jedi",
  "jest",
  "jf",
  "jg",
  "jh",
  "ji",
  "jj",
  "jk",
  "jl",
  "jm",
  "jn",
  "jo",
  "jobs",
  "john",
  "jp",
  "jq",
  "jr",
  "jrun",
  "js",
  "jt",
  "ju",
  "juegos",
  "juliet",
  "juliette",
  "juniper",
  "jupiter",
  "jv",
  "jw",
  "jx",
  "jy",
  "jz",
  "k",
  "ka",
  "kamanda",
  "kansas",
  "kansascity",
  "kappa",
  "kazaa",
  "kb",
  "kc",
  "kd",
  "kdc1",
  "ke",
  "kentucky",
  "kepler",
  "kerberos",
  "kerberos-adm",
  "kerberos4",
  "kerberos_master",
  "kermit",
  "kernel",
  "keynote",
  "keyserver",
  "kf",
  "kg",
  "kh",
  "ki",
  "kilo",
  "king",
  "kirk",
  "kj",
  "kk",
  "kl",
  "klogin",
  "km",
  "kn",
  "knetd",
  "knowledgebase",
  "knoxville",
  "ko",
  "koe",
  "korea",
  "kp",
  "kpasswd",
  "kpop",
  "kq",
  "kr",
  "krb_prop",
  "krbupdate",
  "ks",
  "kshell",
  "kst-core-1",
  "kt",
  "ku",
  "kv",
  "kw",
  "kx",
  "ky",
  "kz",
  "l",
  "l0",
  "l2f",
  "la",
  "lab",
  "laboratories",
  "laboratorio",
  "laboratory",
  "labs",
  "laforge",
  "lambda",
  "lan",
  "lan-gate",
  "laptop",
  "laserjet",
  "lasvegas",
  "launch",
  "lb",
  "lc",
  "ld",
  "ldap",
  "ldap1",
  "ldap2",
  "ldaps",
  "le",
  "learn",
  "legal",
  "leng",
  "lenny",
  "leo",
  "lf",
  "lg",
  "lh",
  "li",
  "lib",
  "library",
  "lim-core-1",
  "lima",
  "lincoln",
  "link",
  "linux",
  "linux0",
  "linux01",
  "linux02",
  "linux1",
  "linux2",
  "linuxconf",
  "lisa",
  "lista",
  "listes",
  "lists",
  "listserv",
  "listserver",
  "live",
  "lj",
  "lk",
  "ll",
  "lm",
  "ln",
  "lo",
  "lo-0",
  "lo-0-0",
  "lo-1",
  "lo0",
  "lo0-0",
  "load",
  "loadbalancer",
  "loc-srv",
  "local",
  "localhost",
  "locsrv",
  "log",
  "log-server",
  "log0",
  "log01",
  "log02",
  "log1",
  "log2",
  "logfile",
  "logfiles",
  "logger",
  "logging",
  "loghost",
  "login",
  "logon",
  "logs",
  "loki",
  "london",
  "longbeach",
  "loopback-0",
  "loopback-1",
  "loopback0",
  "loopback1",
  "lorien",
  "losangeles",
  "lotus",
  "lotusnote",
  "louisiana",
  "lp",
  "lq",
  "lr",
  "ls",
  "lt",
  "lu",
  "luke",
  "lv",
  "lw",
  "lx",
  "ly",
  "lyris",
  "lz",
  "m",
  "m-net",
  "m7i",
  "ma",
  "mac",
  "mac1",
  "mac10",
  "mac11",
  "mac2",
  "mac3",
  "mac4",
  "mac5",
  "mach",
  "macintosh",
  "macos",
  "macosx",
  "madrid",
  "maduin",
  "mag",
  "mail",
  "mail1",
  "mail2",
  "mail3",
  "mail6",
  "mailer",
  "mailgate",
  "mailgw3",
  "mailhost",
  "mailin",
  "mailing",
  "maillist",
  "maillists",
  "mailman",
  "mailq",
  "mailroom",
  "mailserv",
  "mailserver",
  "mailsite",
  "mailsrv",
  "mailtest",
  "main",
  "maine",
  "maint",
  "mall",
  "manage",
  "management",
  "manager",
  "mandelbrot",
  "mandelspawn",
  "manufacturing",
  "map",
  "mapas",
  "maps",
  "mapserver",
  "marketing",
  "marketplace",
  "mars",
  "marvin",
  "mary",
  "maryland",
  "massachusetts",
  "master",
  "max",
  "maxwell",
  "mb",
  "mc",
  "mci",
  "md",
  "mdaemon",
  "mdns",
  "me",
  "media",
  "member",
  "members",
  "memphis",
  "mercury",
  "merlin",
  "messages",
  "messenger",
  "meta",
  "mf",
  "mg",
  "mgmt",
  "mh",
  "mi",
  "miami",
  "michigan",
  "mickey",
  "microsoft-ds",
  "midwest",
  "miembros",
  "mike",
  "milwaukee",
  "minerva",
  "minneapolis",
  "minnesota",
  "miranda",
  "mirror",
  "mirrors",
  "mis",
  "mississippi",
  "missouri",
  "mj",
  "mj0",
  "mj1",
  "mk",
  "ml",
  "mm",
  "mmcc",
  "mn",
  "mng",
  "mngt",
  "mo",
  "mob",
  "mobile",
  "mobileauth",
  "mobilemail",
  "moira_db",
  "moira_update",
  "moira_ureg",
  "mojito",
  "mom",
  "mon",
  "mon1",
  "mon2",
  "monitor",
  "monitor01",
  "monitoring",
  "montana",
  "moodle",
  "moon",
  "mordor",
  "moria",
  "moscow",
  "movies",
  "movil",
  "mozart",
  "mp",
  "mp3",
  "mpeg",
  "mpg",
  "mq",
  "mr",
  "mrtd",
  "mrtg",
  "ms",
  "ms-exchange",
  "ms-sql",
  "msexchange",
  "msnp",
  "msp",
  "mssql",
  "mssql0",
  "mssql01",
  "mssql1",
  "mt",
  "mta",
  "mtp",
  "mtu",
  "mu",
  "multimedia",
  "munin",
  "music",
  "mv",
  "mw",
  "mx",
  "mx0",
  "mx01",
  "mx02",
  "mx03",
  "mx1",
  "mx2",
  "mx3",
  "mx6",
  "my",
  "mysql",
  "mysql0",
  "mysql01",
  "mysql1",
  "mz",
  "n",
  "na",
  "nagios",
  "name",
  "names",
  "nameserv",
  "nameserver",
  "narf",
  "nas",
  "nashville",
  "nat",
  "nb",
  "nbp",
  "nc",
  "nd",
  "ndn-gw",
  "nds",
  "ndtp",
  "ne",
  "nebraska",
  "nelson",
  "neo",
  "neon",
  "neptun",
  "neptune",
  "nessus",
  "net",
  "netapp",
  "netbios",
  "netdata",
  "netgear",
  "netlab",
  "netmail",
  "netmeeting",
  "netnews",
  "netscaler",
  "netscreen",
  "netstat",
  "netstats",
  "netwall",
  "network",
  "nevada",
  "never",
  "new",
  "newhampshire",
  "newjersey",
  "newmexico",
  "neworleans",
  "news",
  "newsfeed",
  "newsfeeds",
  "newsgroups",
  "newton",
  "newyork",
  "newzealand",
  "nextstep",
  "nf",
  "nfs",
  "ng",
  "nh",
  "ni",
  "nic",
  "nigeria",
  "ninstall",
  "nj",
  "nk",
  "nl",
  "nm",
  "nms",
  "nn",
  "nntp",
  "nntps",
  "no",
  "noc",
  "noclog",
  "node",
  "node1",
  "nokia",
  "nombres",
  "nora",
  "north",
  "northcarolina",
  "northdakota",
  "northeast",
  "northwest",
  "noticias",
  "novell",
  "november",
  "np",
  "nq",
  "nqs",
  "nr",
  "ns",
  "ns-",
  "ns-cache",
  "ns-ext",
  "ns0",
  "ns00",
  "ns01",
  "ns02",
  "ns03",
  "ns1",
  "ns10",
  "ns11",
  "ns15",
  "ns2",
  "ns3",
  "ns4",
  "ns5",
  "ns6",
  "ns7",
  "ns9",
  "nsa",
  "nsauth1",
  "nsca",
  "nscache",
  "nscache1",
  "nscache2",
  "nss",
  "nsv6",
  "nt",
  "nt4",
  "nt40",
  "ntalk",
  "ntmail",
  "ntp",
  "ntp0",
  "ntp1",
  "ntp2",
  "ntserver",
  "nu",
  "null",
  "nut",
  "nv",
  "nw",
  "nx",
  "ny",
  "nz",
  "o",
  "oa",
  "oakland",
  "ob",
  "oberon",
  "oc",
  "oc48-pos9-0",
  "ocean",
  "ocsp",
  "od",
  "odin",
  "oe",
  "of",
  "office",
  "offices",
  "og",
  "oh",
  "ohio",
  "oi",
  "oj",
  "ojp-apply",
  "ok",
  "oklahoma",
  "oklahomacity",
  "ol",
  "old",
  "om",
  "omaha",
  "omega",
  "omicron",
  "omirr",
  "omniorb",
  "on",
  "online",
  "ontario",
  "oo",
  "op",
  "open",
  "openbsd",
  "openview",
  "openvpn",
  "operations",
  "ops",
  "ops0",
  "ops01",
  "ops02",
  "ops1",
  "ops2",
  "opsware",
  "oq",
  "or",
  "ora",
  "oracle",
  "orange",
  "oraportal",
  "order",
  "orders",
  "oregon",
  "orion",
  "orlando",
  "os",
  "oscar",
  "ospf6d",
  "ospfapi",
  "ospfd",
  "osx",
  "ot",
  "ou",
  "out",
  "outbound",
  "outgoing",
  "outlook",
  "outside",
  "ov",
  "ow",
  "owa",
  "owa01",
  "owa02",
  "owa1",
  "owa2",
  "ows",
  "ox",
  "oxnard",
  "oy",
  "oz",
  "p",
  "p1-960",
  "pa",
  "packages",
  "page",
  "pager",
  "pages",
  "paginas",
  "pan",
  "panda",
  "panoramix",
  "papa",
  "paris",
  "parners",
  "partner",
  "partners",
  "patch",
  "patches",
  "paul",
  "pawserv",
  "payroll",
  "pb",
  "pbx",
  "pc",
  "pc01",
  "pc1",
  "pc10",
  "pc101",
  "pc11",
  "pc12",
  "pc13",
  "pc14",
  "pc15",
  "pc16",
  "pc17",
  "pc18",
  "pc19",
  "pc2",
  "pc20",
  "pc21",
  "pc22",
  "pc23",
  "pc24",
  "pc25",
  "pc26",
  "pc27",
  "pc28",
  "pc29",
  "pc3",
  "pc30",
  "pc31",
  "pc32",
  "pc33",
  "pc34",
  "pc35",
  "pc36",
  "pc37",
  "pc38",
  "pc39",
  "pc4",
  "pc40",
  "pc41",
  "pc42",
  "pc43",
  "pc44",
  "pc45",
  "pc46",
  "pc47",
  "pc48",
  "pc49",
  "pc5",
  "pc50",
  "pc51",
  "pc52",
  "pc53",
  "pc54",
  "pc55",
  "pc56",
  "pc57",
  "pc58",
  "pc59",
  "pc6",
  "pc60",
  "pc7",
  "pc8",
  "pc9",
  "pcanywhere",
  "pcmail",
  "pcrd",
  "pd",
  "pda",
  "pdc",
  "pe",
  "peach",
  "pegasus",
  "pendrell",
  "pennsylvania",
  "penti",
  "people",
  "peoplesoft",
  "personal",
  "pf",
  "pg",
  "pgp",
  "ph",
  "phi",
  "philadelphia",
  "phobos",
  "phoenix",
  "phoeniz",
  "phone",
  "phones",
  "photo",
  "photos",
  "php",
  "pi",
  "picard",
  "pics",
  "pictures",
  "pink",
  "pipex-gw",
  "pironet",
  "pittsburgh",
  "pix",
  "pj",
  "pk",
  "pki",
  "pl",
  "plano",
  "platinum",
  "plum",
  "pluto",
  "pm",
  "pm1",
  "pn",
  "po",
  "po-1",
  "po-2",
  "po1",
  "po100",
  "po2",
  "policy",
  "polls",
  "pop",
  "pop2",
  "pop3",
  "pop3s",
  "portal",
  "portalipv6",
  "portals",
  "portfolio",
  "portland",
  "pos1-0",
  "posix",
  "post",
  "posta",
  "postales",
  "postaweb",
  "postgresql",
  "postman",
  "postmaster",
  "postoffice",
  "pp",
  "ppp",
  "ppp001",
  "ppp002",
  "ppp003",
  "ppp01",
  "ppp02",
  "ppp03",
  "ppp1",
  "ppp10",
  "ppp11",
  "ppp12",
  "ppp13",
  "ppp14",
  "ppp15",
  "ppp16",
  "ppp17",
  "ppp18",
  "ppp19",
  "ppp2",
  "ppp20",
  "ppp21",
  "ppp3",
  "ppp4",
  "ppp5",
  "ppp6",
  "ppp7",
  "ppp8",
  "ppp9",
  "pptp",
  "pq",
  "pr",
  "pre-prod",
  "predict",
  "prensa",
  "preprod",
  "press",
  "print",
  "printer",
  "printserv",
  "printserver",
  "priv",
  "privacy",
  "privat",
  "private",
  "prj",
  "problemtracker",
  "prod",
  "products",
  "profiles",
  "project",
  "projects",
  "prometheus",
  "promo",
  "proton",
  "proxy",
  "proxy1",
  "proxy2",
  "prueba",
  "pruebas",
  "ps",
  "psi",
  "pss",
  "pt",
  "pu",
  "pub",
  "public",
  "pubs",
  "puck",
  "purple",
  "pv",
  "pw",
  "pwdgen",
  "px",
  "py",
  "pz",
  "q",
  "qa",
  "qb",
  "qc",
  "qd",
  "qe",
  "qf",
  "qg",
  "qh",
  "qi",
  "qj",
  "qk",
  "ql",
  "qm",
  "qmail",
  "qmtp",
  "qn",
  "qo",
  "qotd",
  "qp",
  "qq",
  "qr",
  "qs",
  "qt",
  "qu",
  "quake",
  "quark",
  "quebec",
  "queen",
  "quotes",
  "qv",
  "qw",
  "qx",
  "qy",
  "qz",
  "r",
  "r00",
  "r01",
  "r02",
  "r1",
  "r2",
  "r7-pao1",
  "ra",
  "radio",
  "radius",
  "radius1",
  "radius2",
  "rapidsite",
  "raptor",
  "ras",
  "rb",
  "rc",
  "rcs",
  "rd",
  "re",
  "read",
  "realserver",
  "recruiting",
  "recursive",
  "red",
  "redhat",
  "redirect1",
  "redirect2",
  "ref",
  "reference",
  "reg",
  "register",
  "registro",
  "registry",
  "regs",
  "relay",
  "relay01",
  "relay02",
  "relay2",
  "releases",
  "rem",
  "remote",
  "remotefs",
  "remstats",
  "reports",
  "res1",
  "res2",
  "research",
  "reseller",
  "reserved",
  "resolv1",
  "resolver",
  "resolver1",
  "resolver2",
  "restricted",
  "resumenes",
  "rf",
  "rfe",
  "rg",
  "rh",
  "rho",
  "rhodeisland",
  "ri",
  "ripd",
  "ripe",
  "ripngd",
  "ris",
  "rj",
  "rje",
  "rk",
  "rl",
  "rlp",
  "rm",
  "rmi",
  "rn",
  "rnd",
  "ro",
  "robert",
  "robinhood",
  "romeo",
  "romulus",
  "root",
  "rootd",
  "rose",
  "route",
  "router",
  "router1",
  "router2",
  "rp",
  "rplay",
  "rptp",
  "rq",
  "rr",
  "rr1",
  "rs",
  "rss",
  "rsync",
  "rt",
  "rt2",
  "rtelnet",
  "rtmp",
  "rtr",
  "rtr01",
  "rtr1",
  "rtsp",
  "ru",
  "rune",
  "rv",
  "rw",
  "rwhois",
  "rx",
  "ry",
  "rz",
  "s",
  "s0",
  "s01",
  "s1",
  "s2",
  "sa",
  "sac",
  "sacramento",
  "sadmin",
  "safe",
  "saft",
  "sales",
  "saltlake",
  "sam",
  "sample",
  "samples",
  "san",
  "sanantonio",
  "sandbox",
  "sandiego",
  "sane",
  "sanfrancisco",
  "sanjose",
  "sap",
  "sapgw",
  "sara",
  "saskatchewan",
  "saturn",
  "sb",
  "sbs",
  "sc",
  "scanner",
  "scanner01",
  "schedules",
  "scotland",
  "scotty",
  "sd",
  "se",
  "search",
  "search6",
  "seattle",
  "sec",
  "secret",
  "secure",
  "secured",
  "securid",
  "security",
  "seeweb-gw",
  "seguro",
  "sendmail",
  "seri",
  "serv",
  "serv2",
  "server",
  "server1",
  "server2",
  "server3",
  "server4",
  "server5",
  "server6",
  "servers",
  "service",
  "services",
  "services1",
  "servicio",
  "servicios",
  "servidor",
  "setup",
  "sf",
  "sftp",
  "sg",
  "sh",
  "shannon",
  "shared",
  "sharepoint",
  "shareware",
  "shell",
  "shell1",
  "shipping",
  "shop",
  "shoppers",
  "shopping",
  "si",
  "sidn2",
  "siebel",
  "sierra",
  "sieve",
  "sigma",
  "signin",
  "signup",
  "silc",
  "silver",
  "sim",
  "sip",
  "sip-tls",
  "sirius",
  "site",
  "six",
  "sixxs",
  "sixxs-gw",
  "sj",
  "sk",
  "skkserv",
  "skynet",
  "skywalker",
  "sl",
  "slackware",
  "slmail",
  "sm",
  "smc",
  "sml",
  "smokeping",
  "sms",
  "smsqp",
  "smtp",
  "smtp-out",
  "smtp1",
  "smtp2",
  "smtp3",
  "smtphost",
  "smux",
  "sn",
  "snail",
  "sniffer",
  "snmp",
  "snmp-trap",
  "snmpd",
  "snoopy",
  "snort",
  "snpp",
  "so",
  "so-0-0-0",
  "so-0-0-1",
  "so-0-1-0",
  "so-1-0-0",
  "so-2-0-0",
  "soap",
  "socal",
  "socios",
  "socks",
  "software",
  "sokrates",
  "sol",
  "solaris",
  "solutions",
  "soporte",
  "source",
  "sourcecode",
  "sourcesafe",
  "south",
  "southcarolina",
  "southdakota",
  "southeast",
  "southwest",
  "sp",
  "spain",
  "spam",
  "spamd",
  "spider",
  "spiderman",
  "spl",
  "splunk",
  "spock",
  "spokane",
  "springfield",
  "sprint",
  "sq",
  "sqa",
  "sql",
  "sql0",
  "sql01",
  "sql1",
  "sql7",
  "sqlserver",
  "squid",
  "squirrel",
  "squirrelmail",
  "sr",
  "src",
  "srv",
  "srv02",
  "srv1",
  "ss",
  "ssc",
  "ssh",
  "ssl",
  "ssl0",
  "ssl01",
  "ssl1",
  "ssmtp",
  "st",
  "staff",
  "stage",
  "staging",
  "start",
  "stat",
  "static",
  "statistics",
  "stats",
  "stinky",
  "stlouis",
  "sto-cr1",
  "sto-cr2",
  "sto-cr3",
  "stock",
  "storage",
  "store",
  "storefront",
  "stream",
  "streaming",
  "stronghold",
  "strongmail",
  "studio",
  "su",
  "submission",
  "submit",
  "subversion",
  "suche",
  "sun",
  "sun0",
  "sun01",
  "sun02",
  "sun1",
  "sun2",
  "sunrpc",
  "supdup",
  "superman",
  "supfiledbg",
  "supfilesrv",
  "supplier",
  "suppliers",
  "support",
  "suucp",
  "sv",
  "svc",
  "svn",
  "svr01",
  "svr02",
  "sw",
  "sw-core1",
  "sw0",
  "sw01",
  "sw1",
  "swat",
  "sweden",
  "switch",
  "switzerland",
  "sx",
  "sy",
  "sybase",
  "sydney",
  "sysadmin",
  "sysback",
  "syslog",
  "syslogs",
  "sysrqd",
  "systat",
  "system",
  "sz",
  "t",
  "ta",
  "tacacs",
  "tacacs-ds",
  "tacoma",
  "taiwan",
  "talk",
  "tampa",
  "tango",
  "tao",
  "tarsier",
  "tau",
  "tb",
  "tc",
  "tcl",
  "tcpmux",
  "td",
  "te",
  "te-1-1",
  "te-1-2",
  "te-1-3",
  "te-2-1",
  "te-2-2",
  "te-3-1",
  "team",
  "tech",
  "technology",
  "techsupport",
  "telephone",
  "telephony",
  "telnet",
  "telnets",
  "temp",
  "tempo",
  "ten1-0-0",
  "tennessee",
  "teredo",
  "teredo-gw",
  "teredo-relay",
  "terminal",
  "terminalserver",
  "termserv",
  "terra",
  "terror",
  "test",
  "test2k",
  "testajax",
  "testasp",
  "testaspnet",
  "testbed",
  "testcf",
  "testing",
  "testjsp",
  "testlab",
  "testlinux",
  "testphp",
  "testserver",
  "testsite",
  "testsql",
  "testxp",
  "texas",
  "tf",
  "tfido",
  "tftp",
  "tg",
  "th",
  "thailand",
  "the",
  "theta",
  "thinktank",
  "thor",
  "ti",
  "ticket",
  "tienda",
  "tiger",
  "time",
  "timed",
  "tinc",
  "titan",
  "titania",
  "tivoli",
  "tj",
  "tk",
  "tl",
  "tm",
  "tn",
  "tns",
  "to",
  "toad",
  "tokyo",
  "toledo",
  "tom",
  "tomocha",
  "tool",
  "tools",
  "toplayer",
  "toronto",
  "tour",
  "tp",
  "tproxy",
  "tq",
  "tr",
  "tracker",
  "tracker0",
  "traffic",
  "train",
  "training",
  "transfers",
  "trinidad",
  "trinity",
  "trn1-iana",
  "ts",
  "ts1",
  "tt",
  "tu",
  "tu-0",
  "tu0",
  "tu1",
  "tu2",
  "tu3",
  "tu5",
  "tucson",
  "tulsa",
  "tunnel",
  "tunnel2",
  "tunnelbroker",
  "turing",
  "turtle",
  "tv",
  "tw",
  "tx",
  "ty",
  "tz",
  "u",
  "ua",
  "uat",
  "ub",
  "ubuntu",
  "uc",
  "ud",
  "uddi",
  "ue",
  "uf",
  "ug",
  "uh",
  "ui",
  "uj",
  "uk",
  "ul",
  "ulistserv",
  "ultracopier",
  "um",
  "un",
  "unassigned",
  "undernet-gw",
  "uni",
  "uniform",
  "union",
  "unitedkingdom",
  "unitedstates",
  "unix",
  "unixware",
  "unknown",
  "uo",
  "up",
  "update",
  "updates",
  "upload",
  "uploads",
  "upp-cr1",
  "ups",
  "upsilon",
  "uq",
  "ur",
  "ur01",
  "ur02",
  "ur03",
  "ur04",
  "uranus",
  "urchin",
  "us",
  "us1",
  "usa",
  "usenet",
  "user",
  "users",
  "ut",
  "utah",
  "utilities",
  "uu",
  "uucp",
  "uucp-path",
  "uv",
  "uw",
  "ux",
  "uy",
  "uz",
  "v",
  "v6",
  "v6gw",
  "v6www",
  "va",
  "vaak",
  "vab-core-1",
  "vab2-core-1",
  "vader",
  "vantive",
  "vault",
  "vb",
  "vboxd",
  "vc",
  "vd",
  "vds",
  "ve",
  "ve1",
  "ve8",
  "vega",
  "vegas",
  "vend",
  "vendors",
  "ventas",
  "venus",
  "vermont",
  "vf",
  "vg",
  "vh",
  "vi",
  "victor",
  "video",
  "video6",
  "videos",
  "viking",
  "violet",
  "vip",
  "virginia",
  "virtual",
  "vista",
  "vj",
  "vk",
  "vl",
  "vl10",
  "vl100",
  "vl101",
  "vl102",
  "vlad",
  "vlan1",
  "vlan101",
  "vlan2",
  "vm",
  "vmm",
  "vmserver",
  "vmware",
  "vn",
  "vnc",
  "vnetd",
  "vo",
  "voice",
  "voicemail",
  "voip",
  "vopied",
  "vox",
  "voyager",
  "vp",
  "vpn",
  "sslvpn",
  "ssl-vpn",
  "vpn0",
  "vpn01",
  "vpn02",
  "vpn1",
  "vpn2",
  "vq",
  "vr",
  "vs",
  "vt",
  "vu",
  "vv",
  "vw",
  "vwww01",
  "vx",
  "vy",
  "vz",
  "w",
  "w-03",
  "w-04",
  "w1",
  "w2",
  "w3",
  "wa",
  "wais",
  "wallet",
  "wam",
  "wan",
  "wap",
  "warehouse",
  "warlord",
  "washington",
  "wb",
  "wc",
  "wc3",
  "wd",
  "we",
  "web",
  "web0",
  "web01",
  "web02",
  "web03",
  "web1",
  "web2",
  "web3",
  "webaccess",
  "webadmin",
  "webalizer",
  "webapps03",
  "webboard",
  "webcache",
  "webcam",
  "webcast",
  "webct",
  "webdev",
  "webdocs",
  "webfarm",
  "webhelp",
  "weblib",
  "weblog",
  "weblogic",
  "webmail",
  "webmail01",
  "webmaster",
  "webmin",
  "webproxy",
  "webring",
  "webs",
  "webserv",
  "webserver",
  "webservice",
  "webservices",
  "website",
  "websites",
  "websphere",
  "websrv",
  "websrvr",
  "webstats",
  "webster",
  "webstore",
  "websvr",
  "webtest01",
  "webtrends",
  "welcome",
  "west",
  "westvirginia",
  "wf",
  "wg",
  "wh",
  "wh1",
  "whiskey",
  "white",
  "who",
  "whois",
  "wi",
  "wichita",
  "wiki",
  "wililiam",
  "win",
  "win01",
  "win02",
  "win1",
  "win2",
  "win2000",
  "win2003",
  "win2008",
  "win2k",
  "win2k3",
  "win2k8",
  "windows",
  "windows01",
  "windows02",
  "windows1",
  "windows2",
  "windows2000",
  "windows2003",
  "windows2008",
  "windows7",
  "windowsvista",
  "windowsxp",
  "wingate",
  "winnt",
  "winproxy",
  "wins",
  "winserve",
  "winxp",
  "wire",
  "wireless",
  "wisconsin",
  "wj",
  "wk",
  "wl",
  "wlan",
  "wlan6",
  "wm",
  "wn",
  "wo",
  "wordpress",
  "work",
  "world",
  "wp",
  "wpad",
  "wq",
  "wr",
  "write",
  "ws",
  "ws1",
  "ws10",
  "ws11",
  "ws12",
  "ws13",
  "ws2",
  "ws3",
  "ws4",
  "ws5",
  "ws6",
  "ws7",
  "ws8",
  "ws9",
  "wt",
  "wu",
  "wusage",
  "wv",
  "ww",
  "ww0",
  "ww00",
  "ww01",
  "ww02",
  "ww03",
  "ww1",
  "ww2",
  "ww3",
  "www",
  "www-",
  "www-0",
  "www-00",
  "www-01",
  "www-02",
  "www-03",
  "www-1",
  "www-2",
  "www-3",
  "www-6",
  "www-int",
  "www-ipv6",
  "www-v6",
  "www0",
  "www00",
  "www01",
  "www02",
  "www03",
  "www1",
  "www2",
  "www3",
  "www6",
  "wwwchat",
  "wwwdev",
  "wwwipv6",
  "wwwmail",
  "wwwv6",
  "wx",
  "wy",
  "wyoming",
  "wz",
  "x",
  "x-ray",
  "x11",
  "xa",
  "xanthus",
  "xb",
  "xc",
  "xd",
  "xdmcp",
  "xe",
  "xe-0-0-0",
  "xe-0-1-0",
  "xe-0-2-0",
  "xe-0-2-0-0",
  "xe-0-3-0",
  "xe-1-0-0",
  "xe-1-1-0",
  "xe-1-2-0-0",
  "xe-1-3-0",
  "xe-2-0-0",
  "xe-2-1-0",
  "xe-3-0-0",
  "xen",
  "xf",
  "xg",
  "xh",
  "xi",
  "xj",
  "xk",
  "xl",
  "xlogan",
  "xm",
  "xmail",
  "xml",
  "xmpp-client",
  "xmpp-server",
  "xn",
  "xo",
  "xp",
  "xpilot",
  "xq",
  "xr",
  "xs",
  "xt",
  "xtel",
  "xtell",
  "xu",
  "xv",
  "xw",
  "xx",
  "xy",
  "xz",
  "y",
  "ya",
  "yankee",
  "yb",
  "yc",
  "yd",
  "ye",
  "yellow",
  "yf",
  "yg",
  "yh",
  "yi",
  "yj",
  "yk",
  "yl",
  "ym",
  "yn",
  "yo",
  "young",
  "yp",
  "yq",
  "yr",
  "ys",
  "yt",
  "yu",
  "yv",
  "yw",
  "yx",
  "yy",
  "yz",
  "z",
  "z-log",
  "z3950",
  "za",
  "zb",
  "zc",
  "zd",
  "ze",
  "zebra",
  "zebrasrv",
  "zen",
  "zera",
  "zeus",
  "zf",
  "zg",
  "zh",
  "zi",
  "zip",
  "zj",
  "zk",
  "zl",
  "zlog",
  "zm",
  "zn",
  "zo",
  "zope",
  "zp",
  "zq",
  "zr",
  "zs",
  "zserv",
  "zt",
  "zu",
  "zulu",
  "zv",
  "zw",
  "zx",
  "zy",
  "zz",
  "2607",
  "accelerator",
  "auth0",
  "auth00",
  "cacti",
  "castor",
  "cpr1",
  "d1",
  "dist02",
  "dlv",
  "dns-a",
  "dns-b",
  "dnsa",
  "dnsb",
  "dns6",
  "edge1",
  "excalibur",
  "filesender",
  "gate1",
  "gnu",
  "gw-ipv6",
  "iana",
  "in1",
  "llb1",
  "lo-6",
  "moz",
  "newsfeed2",
  "no-dns-yet",
  "ns12",
  "ns8",
  "ntp3",
  "rns2",
  "sec1",
  "star-gw",
  "te2-1",
  "tge-1-1",
  "uhura",
  "vl-6",
  "vl6-at",
  "vlan-100",
  "vlan100",
  "www-v6v4",
  ""
};


char *sub_srv_test[] = {
  "_1password",
  "_abi-instrument",
  "_xmpp-server",
  "_xmpp-client",
  "_http",
  "_https",
  "_sip",
  "_sips",
  "_hydra",
  "_hyperstream",
  "_iax",
  "_foo",
  "_pop3",
  "_imap",
  "_abc",
  "_zzz",
  ""
};

char *sub_srv[] = {
  "_1password",
  "_abi-instrument",
  "_accessdata-f2d",
  "_accessdata-f2w",
  "_accessone",
  "_accountedge",
  "_acrobatsrv",
  "_actionitems",
  "_activeraid",
  "_activeraid-ssl",
  "_addressbook",
  "_adisk",
  "_adobe-vc",
  "_adpro-setup",
  "_a-d-sync",
  "_aecoretech",
  "_aeroflex",
  "_afpovertcp",
  "_airport",
  "_airprojector",
  "_airsharing",
  "_airsharingpro",
  "_amba-cam",
  "_amiphd-p2p",
  "_animobserver",
  "_animolmd",
  "_anquetsync",
  "_appelezvous",
  "_apple-ausend",
  "_apple-midi",
  "_applerdbg",
  "_apple-sasl",
  "_appletv",
  "_appletv-itunes",
  "_appletv-pair",
  "_aquamon",
  "_asr",
  "_astnotify",
  "_astralite",
  "_async",
  "_atlassianapp",
  "_auth",
  "_autodiscover",
  "_av",
  "_axis-video",
  "_b3d-convince",
  "_babyphone",
  "_bdsk",
  "_beacon",
  "_beamer",
  "_beatpack",
  "_beep",
  "_bfagent",
  "_bigbangchess",
  "_bigbangmancala",
  "_bittorrent",
  "_blackbook",
  "_bluevertise",
  "_bookworm",
  "_bootps",
  "_boundaryscan",
  "_bousg",
  "_bri",
  "_bsqdea",
  "_busycal",
  "_caltalk",
  "_cardsend",
  "_cctv",
  "_cheat",
  "_chess",
  "_chfts",
  "_chili",
  "_cip4discovery",
  "_clipboard",
  "_clique",
  "_clscts",
  "_collection",
  "_com-ocs-es-mcc",
  "_contactserver",
  "_corroboree",
  "_cpnotebook2",
  "_cvspserver",
  "_cw-codetap",
  "_cw-dpitap",
  "_cw-oncetap",
  "_cw-powertap",
  "_cytv",
  "_daap",
  "_dacp",
  "_dancepartner",
  "_dataturbine",
  "_device-info",
  "_difi",
  "_disconnect",
  "_distcc",
  "_dist-opencl",
  "_ditrios",
  "_divelogsync",
  "_dltimesync",
  "_dns-llq",
  "_dns-sd",
  "_dns-update",
  "_domain",
  "_dop",
  "_dossier",
  "_dpap",
  "_dropcopy",
  "_dsl-sync",
  "_dtrmtdesktop",
  "_dvbservdsc",
  "_dxtgsync",
  "_ea-dttx-poker",
  "_earphoria",
  "_eb-amuzi",
  "_ebms",
  "_ebreg",
  "_ecbyesfsgksc",
  "_ecms",
  "_edcp",
  "_egistix",
  "_eheap",
  "_embrace",
  "_ep",
  "_eppc",
  "_erp-scale",
  "_esp",
  "_eucalyptus",
  "_eventserver",
  "_evs-notif",
  "_ewalletsync",
  "_example",
  "_exb",
  "_exec",
  "_extensissn",
  "_eyetvsn",
  "_facespan",
  "_fairview",
  "_faxstfx",
  "_feed-sharing",
  "_firetask",
  "_fish",
  "_fix",
  "_fjork",
  "_fl-purr",
  "_fmpro-internal",
  "_fmserver-admin",
  "_fontagentnode",
  "_foxtrot-serv",
  "_foxtrot-start",
  "_frameforge-lic",
  "_freehand",
  "_frog",
  "_ftp",
  "_ftpcroco",
  "_fv-cert",
  "_fv-key",
  "_fv-time",
  "_garagepad",
  "_gbs-smp",
  "_gbs-stp",
  "_gforce-ssmp",
  "_glasspad",
  "_glasspadserver",
  "_glrdrvmon",
  "_gpnp",
  "_grillezvous",
  "_growl",
  "_guid",
  "_h323",
  "_h323cs",
  "_h323ls",
  "_helix",
  "_help",
  "_hg",
  "_hinz",
  "_hmcp",
  "_homeauto",
  "_home-sharing",
  "_honeywell-vid",
  "_hotwayd",
  "_howdy",
  "_hpr-bldlnx",
  "_hpr-bldwin",
  "_hpr-db",
  "_hpr-rep",
  "_hpr-toollnx",
  "_hpr-toolwin",
  "_hpr-tstlnx",
  "_hpr-tstwin",
  "_hs-off",
  "_htsp",
  "_http",
  "_https",
  "_hydra",
  "_hyperstream",
  "_iax",
  "_ibiz",
  "_ican",
  "_ica-networking",
  "_ichalkboard",
  "_ichat",
  "_iconquer",
  "_idata",
  "_idcws",
  "_idsync",
  "_ifolder",
  "_ihouse",
  "_ii-drills",
  "_ii-konane",
  "_ilynx",
  "_imap",
  "_imaps",
  "_imidi",
  "_indigo-dvr",
  "_inova-ontrack",
  "_ipbroadcaster",
  "_ipp",
  "_ipspeaker",
  "_irelay",
  "_irmc",
  "_iscsi",
  "_ishare",
  "_isparx",
  "_ispq-vc",
  "_isticky",
  "_istorm",
  "_itis-device",
  "_itsrc",
  "_ivef",
  "_iwork",
  "_jcan",
  "_jabber",
  "_jabber-conference",
  "_jeditx",
  "_jini",
  "_jtag",
  "_kerberos",
  "_kerberos-adm",
  "_kerberos-iv",
  "_kerberos-master",
  "_kpasswd",
  "_ktp",
  "_labyrinth",
  "_lan2p",
  "_lanrevagent",
  "_lanrevserver",
  "_lapse",
  "_ldap",
  "_leaf",
  "_lexicon",
  "_liaison",
  "_library",
  "_llrp",
  "_llrp-secure",
  "_lobby",
  "_logicnode",
  "_login",
  "_lonbridge",
  "_lontalk",
  "_lonworks",
  "_lsys-appserver",
  "_lsys-camera",
  "_lsys-ezcfg",
  "_lsys-oamp",
  "_lux-dtp",
  "_lxi",
  "_lyrics",
  "_macfoh",
  "_macfoh-admin",
  "_macfoh-audio",
  "_macfoh-data",
  "_macfoh-db",
  "_macfoh-events",
  "_macfoh-remote",
  "_macminder",
  "_maestro",
  "_magicdice",
  "_mandos",
  "_matrix",
  "_mbconsumer",
  "_mbproducer",
  "_mbserver",
  "_mconnect",
  "_mcrcp",
  "_mediaboard1",
  "_mesamis",
  "_mimer",
  "_mi-raysat",
  "_modolansrv",
  "_moneysync",
  "_moneyworks",
  "_moodring",
  "_mother",
  "_movieslate",
  "_mp3sushi",
  "_mqtt",
  "_mslingshot",
  "_mttp",
  "_mumble",
  "_musicmachine",
  "_mxim-art2",
  "_mxim-ice",
  "_mxs",
  "_mysync",
  "_ncbroadcast",
  "_ncdirect",
  "_ncsyncserver",
  "_neoriders",
  "_net2display",
  "_net-assistant",
  "_netrestore",
  "_newton-dock",
  "_nfs",
  "_nicname",
  "_nssocketport",
  "_ntlx-arch",
  "_ntlx-ent",
  "_ntlx-video",
  "_ntp",
  "_ntx",
  "_obf",
  "_objective",
  "_oce",
  "_odabsharing",
  "_odisk",
  "_od-master",
  "_officetime-sync",
  "_ofocus-conf",
  "_ofocus-sync",
  "_olpc-activity1",
  "_oma-bcast-sg",
  "_omni-bookmark",
  "_omni-live",
  "_openbase",
  "_opencu",
  "_oprofile",
  "_oscit",
  "_ovready",
  "_owhttpd",
  "_owserver",
  "_p2pchat",
  "_panoply",
  "_parabay-p2p",
  "_parentcontrol",
  "_parliant",
  "_passwordwallet",
  "_pcast",
  "_pdl-datastream",
  "_pgpkey-hkp",
  "_pgpkey-http",
  "_pgpkey-https",
  "_pgpkey-ldap",
  "_pgpkey-mailto",
  "_photoparata",
  "_pictua",
  "_piesync",
  "_piu",
  "_poch",
  "_pokeeye",
  "_pop3",
  "_pop3s",
  "_postgresql",
  "_powereasy-erp",
  "_powereasy-pos",
  "_pplayer-ctrl",
  "_presence",
  "_print-caps",
  "_printer",
  "_printer._sub._http",
  "_profilemac",
  "_prolog",
  "_protonet",
  "_psap",
  "_psia",
  "_ptnetprosrv2",
  "_ptp",
  "_ptp-req",
  "_puzzle",
  "_qbox",
  "_qttp",
  "_quinn",
  "_radioepg",
  "_radiotag",
  "_radiovis",
  "_rakket",
  "_raop",
  "_rbr",
  "_rce",
  "_rdp",
  "_realplayfavs",
  "_recipe",
  "_remote",
  "_remoteburn",
  "_renderpipe",
  "_rendezvouspong",
  "_renkara-sync",
  "_resacommunity",
  "_resol-vbus",
  "_retrospect",
  "_rfb",
  "_rfbc",
  "_rfid",
  "_riousbprint",
  "_roku-rcp",
  "_rql",
  "_rsmp-server",
  "_rsync",
  "_rtsp",
  "_rubygems",
  "_safarimenu",
  "_sallingbridge",
  "_sallingclicker",
  "_salutafugijms",
  "_sandvox",
  "_scanner",
  "_sc-golf",
  "_schick",
  "_scone",
  "_scpi-raw",
  "_scpi-telnet",
  "_sdsharing",
  "_see",
  "_seeCard",
  "_senteo-http",
  "_sentillion-vlc",
  "_sentillion-vlt",
  "_sepvsync",
  "_serendipd",
  "_servereye",
  "_servermgr",
  "_services",
  "_sessionfs",
  "_sflow",
  "_sftp-ssh",
  "_sge-exec",
  "_sge-qmaster",
  "_shell",
  "_shifter",
  "_shipsgm",
  "_shipsinvit",
  "_shoppersync",
  "_shoutcast",
  "_simmon",
  "_simusoftpong",
  "_sip",
  "_sips",
  "_sipuri",
  "_sironaxray",
  "_skype",
  "_sleep-proxy",
  "_slimcli",
  "_slimhttp",
  "_smartenergy",
  "_smb",
  "_sms",
  "_soap",
  "_socketcloud",
  "_souschef",
  "_sox",
  "_sparechange",
  "_sparql",
  "_spearcat",
  "_spike",
  "_spincrisis",
  "_splashsync",
  "_spl-itunes",
  "_spr-itunes",
  "_ssh",
  "_ssscreenshare",
  "_stanza",
  "_stickynotes",
  "_strateges",
  "_submission",
  "_supple",
  "_surveillus",
  "_svn",
  "_swcards",
  "_switcher",
  "_swordfish",
  "_sxqdea",
  "_sybase-tds",
  "_syncopation",
  "_syncqdea",
  "_synergy",
  "_synksharing",
  "_taccounting",
  "_tango",
  "_tapinoma-ecs",
  "_taskcoachsync",
  "_tbricks",
  "_tcode",
  "_tcu",
  "_teamlist",
  "_te-faxserver",
  "_teleport",
  "_telnet",
  "_tera-fsmgr",
  "_tera-mp",
  "_tf-redeye",
  "_tftp",
  "_thumbwrestling",
  "_ticonnectmgr",
  "_timbuktu",
  "_tinavigator",
  "_tivo-hme",
  "_tivo-music",
  "_tivo-photos",
  "_tivo-remote",
  "_tivo-videos",
  "_todogwa",
  "_tomboy",
  "_toothpicserver",
  "_touch-able",
  "_touch-remote",
  "_tri-vis-client",
  "_tri-vis-server",
  "_tryst",
  "_tt4inarow",
  "_ttcheckers",
  "_ttp4daemon",
  "_tunage",
  "_tuneranger",
  "_ubertragen",
  "_uddi",
  "_uddi-inq",
  "_uddi-pub",
  "_uddi-sec",
  "_uddi-sub",
  "_upnp",
  "_urlbookmark",
  "_uswi",
  "_utest",
  "_uwsgi",
  "_ve-decoder",
  "_ve-encoder",
  "_ve-recorder",
  "_visel",
  "_volley",
  "_vos",
  "_vue4rendercow",
  "_vxi-11",
  "_walkietalkie",
  "_webdav",
  "_webdavs",
  "_webissync",
  "_wedraw",
  "_we-jell",
  "_whamb",
  "_whistler",
  "_wired",
  "_witap",
  "_witapvoice",
  "_wkgrpsvr",
  "_workgroup",
  "_workstation",
  "_wormhole",
  "_writietalkie",
  "_ws",
  "_wtc-heleos",
  "_wtc-qels",
  "_wtc-rex",
  "_wtc-viscostar",
  "_wtc-wpr",
  "_wwdcpic",
  "_xcodedistcc",
  "_xgate-rmi",
  "_xgrid",
  "_xmms2",
  "_xmp",
  "_xmpp-client",
  "_xmpp-server",
  "_x-on",
  "_x-plane9",
  "_xsanclient",
  "_xsanserver",
  "_xsansystem",
  "_xserveraid",
  "_xsync",
  "_xtimelicence",
  "_xtshapro",
  "_xul-http",
  "_yakumo",
  ""
};
